@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: horde/admin/setup/index.php,v 1.28.4.2 2005/01/03 12:25:29 jan Exp $
+ * $Horde: horde/admin/setup/index.php,v 1.28.4.8 2005/08/24 13:42:19 selsky Exp $
  *
  * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2005 Jon Parise <jon@horde.org>
@@ -45,7 +45,7 @@ function _uploadFTP($params)
     $params['hostspec'] = 'localhost';
     $vfs = &VFS::singleton('ftp', $params);
     if (is_a($vfs, 'PEAR_Error')) {
-        $notification->push(sprintf(_("Could not connect to server '%s' using FTP: %s"), $params['hostspec'], $vfs->getMessage()), 'horde.error');
+        $notification->push(sprintf(_("Could not connect to server \"%s\" using FTP: %s"), $params['hostspec'], $vfs->getMessage()), 'horde.error');
         return false;
     }
 
@@ -55,7 +55,7 @@ function _uploadFTP($params)
         $path = $registry->get('fileroot', $app) . '/config';
         /* Try to back up the current conf.php. */
         if ($vfs->exists($path, 'conf.php')) {
-            if (($result = $vfs->copy($path, 'conf.php', $path . '/conf.php.bak')) === true) {
+            if (($result = $vfs->rename($path, 'conf.php', $path, 'conf.php.bak')) === true) {
                 $notification->push(_("Successfully saved backup configuration."), 'horde.success');
             } elseif (is_a($result, 'PEAR_Error')) {
                 $notification->push(sprintf(_("Could not save a backup configuation: %s"), $result->getMessage()), 'horde.error');
@@ -67,9 +67,9 @@ function _uploadFTP($params)
         $write = $vfs->writeData($path, 'conf.php', $config);
         if (is_a($write, 'PEAR_Error')) {
             $no_errors = false;
-            $notification->push(sprintf(_("Could not write configuration for '%s': %s"), $app, $write->getMessage()), 'horde.error');
+            $notification->push(sprintf(_("Could not write configuration for \"%s\": %s"), $app, $write->getMessage()), 'horde.error');
         } else {
-            $notification->push(sprintf(_("Successfully wrote %s"), $path . '/conf.php'), 'horde.success');
+            $notification->push(sprintf(_("Successfully wrote %s"), Util::realPath($path . '/conf.php')), 'horde.success');
             unset($_SESSION['_config'][$app]);
         }
     }
@@ -99,9 +99,18 @@ foreach ($a as $app) {
     $conf_link = Horde::link($conf_link, sprintf(_("Configure %s"), $app), '', '', '', sprintf(_("Configure %s"), $app));
     $apps[$i]['sort'] = $registry->get('name', $app) . ' (' . $app . ')';
     $apps[$i]['name'] = $conf_link . $apps[$i]['sort'] . '</a>';
+    $apps[$i]['version'] = '';
+    if (is_readable($registry->get('fileroot', $app) . '/lib/version.php')) {
+        require_once $registry->get('fileroot', $app) . '/lib/version.php';
+        eval('$defined = defined(\'' . strtoupper($app) . '_VERSION\');');
+        if ($defined) {
+            eval('$ver = ' . strtoupper($app) . '_VERSION;');
+            $apps[$i]['version'] = $ver;
+        }
+    }
     if (!file_exists($path . '/conf.php')) {
         /* No conf.php exists. */
-        $apps[$i]['conf'] = $conf_link . $error;
+        $apps[$i]['conf'] = $conf_link . $error . '</a>';
         $apps[$i]['status'] = _("Missing configuration. You have to generate it now if you want to use this application.");
     } else {
         /* A conf.php exists, get the xml version. */
@@ -120,9 +129,9 @@ foreach ($a as $app) {
         }
 
         if ($xml_ver != $php_ver) {
-            /* Versions are not the same, configuration needs updating. */
+            /* Versions are not the same, configuration is out of date. */
             $apps[$i]['conf'] = $conf_link . $error . '</a>';
-            $apps[$i]['status'] = _("Configuration needs updating.");
+            $apps[$i]['status'] = _("Configuration is out of date.");
             continue;
         } else {
             /* Configuration is ok. */
@@ -206,7 +215,7 @@ $template->set('ftpform', $ftpform, true);
 $template->set('notify', Util::bufferOutput(array($notification, 'notify')));
 $template->setOption('gettext', true);
 
-$title = sprintf(_("%s Configuration"), $registry->get('name', 'horde'));
+$title = sprintf(_("%s Setup"), $registry->get('name', 'horde'));
 require HORDE_TEMPLATES . '/common-header.inc';
 require HORDE_TEMPLATES . '/admin/common-header.inc';
 echo $template->fetch(HORDE_TEMPLATES . '/admin/setup/index.html');
