@@ -60,15 +60,14 @@ define('AUTH_REASON_SESSIONIP', 'sessionip');
  * The Auth:: class provides a common abstracted interface into the various
  * backends for the Horde authentication system.
  *
- * $Horde: framework/Auth/Auth.php,v 1.142 2004/10/29 21:21:54 chuck Exp $
+ * $Horde: framework/Auth/Auth.php,v 1.142.10.12 2005/09/12 16:42:56 selsky Exp $
  *
- * Copyright 1999-2004 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did
  * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.142 $
  * @since   Horde 1.3
  * @package Horde_Auth
  */
@@ -78,7 +77,7 @@ class Auth {
      * An array of capabilities, so that the driver can report which
      * operations it supports and which it doesn't.
      *
-     * @var array $capabilities
+     * @var array
      */
     var $capabilities = array('add'           => false,
                               'update'        => false,
@@ -91,7 +90,7 @@ class Auth {
    /**
     * Hash containing parameters.
     *
-    * @var array $_params
+    * @var array
     */
     var $_params = array();
 
@@ -100,7 +99,7 @@ class Auth {
      *
      * @access protected
      *
-     * @var array $_authCredentials
+     * @var array
      */
     var $_authCredentials = array();
 
@@ -118,8 +117,6 @@ class Auth {
      * Finds out if a set of login credentials are valid, and if requested,
      * mark the user as logged in in the current session.
      *
-     * @access public
-     *
      * @param string $userId      The userId to check.
      * @param array $credentials  The credentials to check.
      * @param boolean $login      Whether to log the user in. If false, we'll
@@ -155,6 +152,16 @@ class Auth {
         );
 
         if ($this->_authenticate($userId, $credentials)) {
+            if (!empty($conf['hooks']['postauthenticate'])) {
+                include_once HORDE_BASE . '/config/hooks.php';
+                if (function_exists('_horde_hook_postauthenticate')) {
+                    if (!call_user_func('_horde_hook_postauthenticate', $userId, $credentials, $realm)) {
+                        $this->_setAuthError(AUTH_REASON_FAILED);
+                        return false;
+                    }
+                }
+            }
+
             if ($login) {
                 $this->setAuth($this->_authCredentials['userId'],
                                $this->_authCredentials['credentials'],
@@ -172,24 +179,12 @@ class Auth {
             }
         }
 
-        if (!empty($conf['hooks']['postauthenticate'])) {
-            include_once HORDE_BASE . '/config/hooks.php';
-            if (function_exists('_horde_hook_postauthenticate')) {
-                if (!call_user_func('_horde_hook_postauthenticate', $userId, $credentials, $realm)) {
-                    $this->_setAuthError(AUTH_REASON_FAILED);
-                    return false;
-                }
-            }
-        }
-
         return $auth;
     }
 
     /**
      * Formats a password using the current encryption.
      *
-     * @access public
-     *
      * @param string $plaintext      The plaintext password to encrypt.
      * @param string $salt           The salt to use to encrypt the password.
      *                               If not present, a new salt will be
@@ -286,12 +281,10 @@ class Auth {
     }
 
     /**
-     * Returns a salt for the appropriate kind of password
-     * encryption. Optionally takes a seed and a plaintext password, to
-     * extract the seed of an existing password, or for encryption types that
-     * use the plaintext in the generation of the salt.
-     *
-     * @access public
+     * Returns a salt for the appropriate kind of password encryption.
+     * Optionally takes a seed and a plaintext password, to extract the seed of
+     * an existing password, or for encryption types that use the plaintext in
+     * the generation of the salt.
      *
      * @param string $encryption  The kind of pasword encryption to use.
      *                            Defaults to md5-hex.
@@ -346,7 +339,6 @@ class Auth {
         case 'aprmd5':
             /**
              * 64 characters that are valid for APRMD5 passwords.
-             * @var string $_APRMD5
              */
             $APRMD5 = './0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
 
@@ -371,9 +363,9 @@ class Auth {
      */
     function genRandomPassword()
     {
-        $vowels     ='aeiouy';
-        $constants  ='bcdfghjklmnpqrstvwxz';
-        $numbers    ='0123456789';
+        $vowels    = 'aeiouy';
+        $constants = 'bcdfghjklmnpqrstvwxz';
+        $numbers   = '0123456789';
 
         /* Alternate constant and vowel random chars with two random numbers
          * at the end. This should produce a fairly pronounceable password. */
@@ -391,7 +383,6 @@ class Auth {
     /**
      * Adds a set of authentication credentials.
      *
-     * @access public
      * @abstract
      *
      * @param string $userId      The userId to add.
@@ -407,7 +398,6 @@ class Auth {
     /**
      * Updates a set of authentication credentials.
      *
-     * @access public
      * @abstract
      *
      * @param string $oldID        The old userId.
@@ -424,7 +414,6 @@ class Auth {
     /**
      * Deletes a set of authentication credentials.
      *
-     * @access public
      * @abstract
      *
      * @param string $userId  The userId to delete.
@@ -461,7 +450,6 @@ class Auth {
     /**
      * Lists all users in the system.
      *
-     * @access public
      * @abstract
      *
      * @return mixed  The array of userIds, or a PEAR_Error object on failure.
@@ -474,7 +462,6 @@ class Auth {
     /**
      * Checks if $userId exists in the system.
      *
-     * @access public
      * @abstract
      *
      * @return boolean  Whether or not $userId already exists.
@@ -488,7 +475,6 @@ class Auth {
      * Automatic authentication: Finds out if the client matches an allowed IP
      * block.
      *
-     * @access public
      * @abstract
      *
      * @return boolean  Whether or not the client is allowed.
@@ -503,8 +489,6 @@ class Auth {
      * specified user. If there isn't, but the configured Auth driver supports
      * transparent authentication, then we try that.
      *
-     * @access public
-     *
      * @param string $realm  The authentication realm to check.
      *
      * @return boolean  Whether or not the user is authenticated.
@@ -540,8 +524,6 @@ class Auth {
     /**
      * Returns the currently logged in user, if there is one.
      *
-     * @access public
-     *
      * @return mixed  The userId of the current user, or false if no user is
      *                logged in.
      */
@@ -561,8 +543,6 @@ class Auth {
      * Returns the curently logged-in user without any domain information
      * (e.g., bob@example.com would be returned as 'bob').
      *
-     * @access public
-     *
      * @return mixed  The user ID of the current user, or false if no user
      *                is logged in.
      */
@@ -579,12 +559,30 @@ class Auth {
         return $user;
     }
 
+    /**
+     * Returns the domain of currently logged-in user (e.g.,
+     * bob@example.com would be returned as 'example.com').
+     *
+     * @since Horde 3.0.6
+     *
+     * @return mixed  The domain suffix of the current user, or false.
+     */
+    function getAuthDomain()
+    {
+        if ($user = Auth::getAuth()) {
+            $pos = strpos($user, '@');
+            if ($pos !== false) {
+                return substr($user, $pos + 1);
+            }
+        }
+
+        return false;
+    }
+
     /**
      * Returns the requested credential for the currently logged in user, if
      * present.
      *
-     * @access public
-     *
      * @param string $credential  The credential to retrieve.
      *
      * @return mixed  The requested credential, or false if no user is
@@ -611,8 +609,6 @@ class Auth {
     /**
      * Sets the requested credential for the currently logged in user.
      *
-     * @access public
-     *
      * @param string $credential  The credential to set.
      * @param string $value       The value to set the credential to.
      */
@@ -638,8 +634,6 @@ class Auth {
      * If a user name hook was defined in the configuration, it gets applied
      * to the userId at this point.
      *
-     * @access public
-     *
      * @param string $userId      The userId who has been authorized.
      * @param array $credentials  The credentials of the user.
      * @param string $realm       The authentication realm to use.
@@ -677,6 +671,7 @@ class Auth {
 
         /* Reload preferences for the new user. */
         $GLOBALS['registry']->loadPrefs();
+        NLS::setLang($GLOBALS['prefs']->getValue('language'));
 
         /* Fetch the user's last login time. */
         $old_login = @unserialize($GLOBALS['prefs']->getValue('last_login'));
@@ -704,8 +699,6 @@ class Auth {
     /**
      * Clears any authentication tokens in the current session.
      *
-     * @access public
-     *
      * @param string $realm  The authentication realm to clear.
      */
     function clearAuth($realm = null)
@@ -727,8 +720,6 @@ class Auth {
     /**
      * Is the current user an administrator?
      *
-     * @access public
-     *
      * @param string $permission  Allow users with this permission admin access
      *                            in the current context.
      * @param integer $permlevel  The level of permissions to check for
@@ -818,8 +809,6 @@ class Auth {
      * Queries the current Auth object to find out if it supports the given
      * capability.
      *
-     * @access public
-     *
      * @param string $capability  The capability to test for.
      *
      * @return boolean  Whether or not the capability is supported.
@@ -833,8 +822,6 @@ class Auth {
      * Returns the URI of the login screen for the current authentication
      * method.
      *
-     * @access public
-     *
      * @param string $app  The application to use.
      * @param string $url  The URL to redirect to after login.
      *
@@ -850,8 +837,6 @@ class Auth {
     /**
      * Returns the named parameter for the current auth driver.
      *
-     * @access public
-     *
      * @param string $param  The parameter to fetch.
      *
      * @return string  The parameter's value.
@@ -864,8 +849,6 @@ class Auth {
     /**
      * Returns the name of the authentication provider.
      *
-     * @access public
-     *
      * @param string $driver  Used by recursive calls when untangling composite
      *                        auth.
      * @param array  $params  Used by recursive calls when untangling composite
@@ -903,8 +886,6 @@ class Auth {
     /**
      * Returns the logout reason.
      *
-     * @access public
-     *
      * @return string One of the logout reasons (see the AUTH_LOGOUT_*
      *                constants for the valid reasons).  Returns null if there
      *                is no logout reason present.
@@ -921,8 +902,6 @@ class Auth {
     /**
      * Returns the status string to use for logout messages.
      *
-     * @access public
-     *
      * @return string  The logout reason string.
      */
     function getLogoutReasonString()
@@ -974,8 +953,6 @@ class Auth {
      * If no reason/msg is passed in, use the current global authentication
      * error message.
      *
-     * @access public
-     *
      * @param string $url     The URL to redirect to.
      * @param string $reason  The reason for logout.
      * @param string $msg     If reason is AUTH_REASON_MESSAGE, the message to
@@ -1111,7 +1088,6 @@ class Auth {
     {
         /**
          * 64 characters that are valid for APRMD5 passwords.
-         * @var string $_APRMD5
          */
         $APRMD5 = './0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
 
@@ -1138,7 +1114,8 @@ class Auth {
         $bin = '';
         $length = strlen($hex);
         for ($i = 0; $i < $length; $i += 2) {
-            $bin .= chr(array_shift(sscanf(substr($hex, $i, 2), '%x')));
+            $tmp = sscanf(substr($hex, $i, 2), '%x');
+            $bin .= chr(array_shift($tmp));
         }
         return $bin;
     }
@@ -1146,8 +1123,6 @@ class Auth {
     /**
      * Attempts to return a concrete Auth instance based on $driver.
      *
-     * @access public
-     *
      * @param mixed $driver  The type of concrete Auth subclass to return. This
      *                       is based on the storage driver ($driver). The code
      *                       is dynamically included. If $driver is an array,
@@ -1206,8 +1181,6 @@ class Auth {
      *
      * This method must be invoked as: $var = &Auth::singleton()
      *
-     * @access public
-     *
      * @param string $driver  The type of concrete Auth subclass to return.
      *                        This is based on the storage driver ($driver).
      *                        The code is dynamically included.
