@@ -4,12 +4,11 @@
  * application-provided Horde authentication which fits inside the
  * Horde Auth:: API.
  *
- * Required parameters:
- * ====================
- *   'app'  --  The application which is providing authentication.
+ * Required parameters:<pre>
+ *   'app'  The application which is providing authentication.</pre>
  *
  *
- * $Horde: framework/Auth/Auth/application.php,v 1.27.10.4 2005/01/03 12:18:52 jan Exp $
+ * $Horde: framework/Auth/Auth/application.php,v 1.27.10.9 2005/07/03 04:26:58 selsky Exp $
  *
  * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -26,7 +25,7 @@ class Auth_application extends Auth {
      * An array of capabilities, so that the driver can report which
      * operations it supports and which it doesn't.
      *
-     * @var array $capabilities
+     * @var array
      */
     var $capabilities = array('add'           => false,
                               'update'        => false,
@@ -38,9 +37,7 @@ class Auth_application extends Auth {
     /**
      * Constructs a new Application authentication object.
      *
-     * @access public
-     *
-     * @param optional array $params  A hash containing connection parameters.
+     * @param array $params  A hash containing connection parameters.
      */
     function Auth_application($params = array())
     {
@@ -51,8 +48,6 @@ class Auth_application extends Auth {
      * Queries the current Auth object to find out if it supports the given
      * capability.
      *
-     * @access public
-     *
      * @param string $capability  The capability to test for.
      *
      * @return boolean  Whether or not the capability is supported.
@@ -88,7 +83,7 @@ class Auth_application extends Auth {
                                   'authentication application');
 
         if (empty($GLOBALS['registry']->applications[$params['app']])) {
-            Horde::fatal(PEAR::raiseError($params['app'] . ' is not configured in the Horde Registry.'), __FILE__, __LINE__);
+            Horde::fatal($params['app'] . ' is not configured in the Horde Registry.', __FILE__, __LINE__);
         }
 
         $this->_params = $params;
@@ -107,7 +102,7 @@ class Auth_application extends Auth {
     function _authenticate($userId, $credentials)
     {
         if (!$GLOBALS['registry']->hasMethod('authenticate', $this->_params['app'])) {
-            Horde::fatal(PEAR::raiseError($this->_params['app'] . ' does not provide an authenticate() method.'), __FILE__, __LINE__);
+            Horde::fatal($this->_params['app'] . ' does not provide an authenticate() method.', __FILE__, __LINE__);
         }
         return $GLOBALS['registry']->callByPackage($this->_params['app'], 'authenticate',
                                                    array('userId' => $userId,
@@ -116,13 +111,10 @@ class Auth_application extends Auth {
     }
 
     /**
-     * Return the URI of the login screen for this authentication
-     * method.
+     * Return the URI of the login screen for this authentication method.
      *
-     * @access public
-     *
-     * @param optional string $app  The application to use.
-     * @param optional string $url  The URL to redirect to after login.
+     * @param string $app  The application to use.
+     * @param string $url  The URL to redirect to after login.
      *
      * @return string  The login screen URI.
      */
@@ -134,8 +126,6 @@ class Auth_application extends Auth {
     /**
      * List all users in the system.
      *
-     * @access public
-     *
      * @return mixed  The array of userIds, or a PEAR_Error object on failure.
      */
     function listUsers()
@@ -150,8 +140,6 @@ class Auth_application extends Auth {
     /**
      * Add a set of authentication credentials.
      *
-     * @access public
-     *
      * @param string $userId      The userId to add.
      * @param array $credentials  The credentials to use.
      *
@@ -169,8 +157,6 @@ class Auth_application extends Auth {
     /**
      * Update a set of authentication credentials.
      *
-     * @access public
-     *
      * @param string $oldID       The old userId.
      * @param string $newID       The new userId.
      * @param array $credentials  The new credentials
@@ -189,8 +175,6 @@ class Auth_application extends Auth {
     /**
      * Delete a set of authentication credentials.
      *
-     * @access public
-     *
      * @param string $userId  The userId to delete.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
