@@ -1,18 +1,17 @@
 <?php
 /**
  * The Auth_imsp class provides basic authentication against an IMSP server.
- * This will be most benificial if already using an IMSP based prefernece system or
- * IMSP based addressbook system
+ * This will be most benificial if already using an IMSP based preference
+ * system or IMSP based addressbook system
  *
- * $Horde: framework/Auth/Auth/imsp.php,v 1.2.10.1 2005/01/03 12:18:52 jan Exp $
+ * $Horde: framework/Auth/Auth/imsp.php,v 1.2.10.8 2005/08/23 17:14:42 mrubinsk Exp $
  *
- * Copyright 2004-2005 Michael Rubinsky <mike@theupstairsroom.com>
+ * Copyright 2004-2005 Michael Rubinsky <mrubinsk@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @author  Michael Rubinsky <mike@theupstairsroom.com>
- * @version $Revision: 1.2.10.1 $
+ * @author  Michael Rubinsky <mrubinsk@horde.org>
  * @package Horde_Auth
  */
 class Auth_imsp extends Auth{
@@ -21,7 +20,7 @@ class Auth_imsp extends Auth{
      * An array of capabilities, so that the driver can report which
      * operations it supports and which it doesn't.
      *
-     * @var array $capabilities
+     * @var array
      */
     var $capabilities = array('add'           => false,
                               'update'        => false,
@@ -32,8 +31,7 @@ class Auth_imsp extends Auth{
     /**
      * Constructor function. Creates new Auth_imsp object.
      *
-     * @access public
-     * @param optional array $params A hash containing parameters.
+     * @param array $params A hash containing parameters.
      */
     function Auth_imsp($params = array())
     {
@@ -44,26 +42,26 @@ class Auth_imsp extends Auth{
      * Private authentication function.
      *
      * @access private
+     *
      * @param string $userID Username for IMSP server.
      * @param array $credentials Hash containing 'password' element.
+     *
      * @return boolean True on success / False on failure.
      */
     function _authenticate($userID, $credentials)
     {
         require_once 'Net/IMSP/Auth.php';
 
-        $params = array();
-        $params['username'] = $userID;
-        $params['password'] = $credentials['password'];
-        $params['server'] = $this->_params['server'];
-        $params['port'] = $this->_params['port'];
+        $this->_params['username'] = $userID;
+        $this->_params['password'] = $credentials['password'];
         $imsp = &Net_IMSP_Auth::singleton($this->_params['auth_method']);
-        if (is_a($imsp, 'PEAR_Error')){
+        if (is_a($imsp, 'PEAR_Error')) {
             return $imsp;
         }
 
-        $result = $imsp->authenticate($params, false);
-        if (is_a($result, 'PEAR_Error')){
+
+        $result = $imsp->authenticate($this->_params, false);
+        if (is_a($result, 'PEAR_Error')) {
             $this->_setAuthError(AUTH_REASON_BADLOGIN);
             return false;
         } else {
@@ -79,11 +77,9 @@ class Auth_imsp extends Auth{
      */
     function _setParams($params)
     {
-        if (empty($params['auth_method'])){
-            $params['auth_method'] = 'plaintext';
-        }
-
-        $this->_params = $params;
+        $this->_params['server'] = $params['server'];
+        $this->_params['port'] = $params['port'];
+        $this->_params['auth_method'] = $params['auth_method'];
     }
 
 }
