@@ -11,13 +11,12 @@
  *
  *      http://www.math.ohio-state.edu/~ccunning/pam_auth/
  *
- * Optional parameters:
- * ====================
- *   'service'  --  The name of the PAM service to use when authenticating.
- *                  DEFAULT: php
+ * Optional parameters:<pre>
+ *   'service'  The name of the PAM service to use when authenticating.
+ *              DEFAULT: php</pre>
  *
  *
- * $Horde: framework/Auth/Auth/pam.php,v 1.3.10.1 2005/01/03 12:18:52 jan Exp $
+ * $Horde: framework/Auth/Auth/pam.php,v 1.3.10.7 2005/07/07 18:15:17 selsky Exp $
  *
  * Copyright 2004-2005 Jon Parise <jon@horde.org>
  *
@@ -25,17 +24,16 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jan Parise <jon@horde.org>
- * @version $Revision: 1.3.10.1 $
  * @since   Horde 3.0
  * @package Horde_Auth
  */
-class Auth_pam extends Auth
-{
+class Auth_pam extends Auth {
+
     /**
      * An array of capabilities, so that the driver can report which
      * operations it supports and which it doesn't.
      *
-     * @var array $capabilities
+     * @var array
      */
     var $capabilities = array('add'           => false,
                               'update'        => false,
@@ -47,9 +45,7 @@ class Auth_pam extends Auth
     /**
      * Constructs a new PAM authentication object.
      *
-     * @access public
-     *
-     * @param optional array $params  A hash containing connection parameters.
+     * @param array $params  A hash containing connection parameters.
      */
     function Auth_pam($params = array())
     {
@@ -76,11 +72,11 @@ class Auth_pam extends Auth
     function _authenticate($userId, $credentials)
     {
         if (empty($credentials['password'])) {
-            Horde::fatal(PEAR::raiseError(_("No password provided for Login authentication.")), __FILE__, __LINE__);
+            Horde::fatal(_("No password provided for Login authentication."), __FILE__, __LINE__);
         }
 
         if (!extension_loaded('pam_auth')) {
-            Horde::fatal(PEAR::raiseError(_("PAM authentication is not available.")), __FILE__, __LINE__);
+            Horde::fatal(_("PAM authentication is not available."), __FILE__, __LINE__);
         }
 
         if (!pam_auth($userId, $credentials['password'], &$error)) {
