@@ -2,7 +2,7 @@
 /**
  * Horde_CLI:: API for basic command-line functionality/checks.
  *
- * $Horde: framework/CLI/CLI.php,v 1.42.6.1 2005/01/03 12:18:54 jan Exp $
+ * $Horde: framework/CLI/CLI.php,v 1.42.6.8 2005/08/24 14:04:36 selsky Exp $
  *
  * Copyright 2003-2005 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2003-2005 Jan Schneider <jan@horde.org>
@@ -12,7 +12,6 @@
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jan Schneider <jan@horde.org>
- * @version $Revision: 1.42.6.1 $
  * @since   Horde 3.0
  * @package Horde_CLI
  */
@@ -20,31 +19,36 @@ class Horde_CLI {
 
     /**
      * Are we running on a console?
-     * @var bool $_console
+     *
+     * @var boolean
      */
     var $_console;
 
     /**
      * The newline string to use.
-     * @var string $_newline
+     *
+     * @var string
      */
     var $_newline;
 
     /**
      * The indent string to use.
-     * @var string $_indent
+     *
+     * @var string
      */
     var $_indent;
 
     /**
      * The string to mark the beginning of bold text.
-     * @var string $_bold_start
+     *
+     * @var string
      */
     var $_bold_start = '';
 
     /**
      * The string to mark the end of bold text.
-     * @var string $_bold_start
+     *
+     * @var string
      */
     var $_bold_end = '';
 
@@ -195,10 +199,9 @@ class Horde_CLI {
     /**
      * Displays a message.
      *
-     * @param string $event          The message string.
-     * @param optional string $type  The type of message: 'cli.error',
-     *                               'cli.warning', 'cli.success', or
-     *                               'cli.message'.
+     * @param string $event  The message string.
+     * @param string $type   The type of message: 'cli.error', 'cli.warning',
+     *                       'cli.success', or 'cli.message'.
      */
     function message($message, $type = 'cli.message')
     {
@@ -232,7 +235,7 @@ class Horde_CLI {
     {
         $this->writeln($this->red('===================='));
         $this->writeln();
-        $this->writeln($this->red(_("Fatal Error!")));
+        $this->writeln($this->red(_("Fatal Error:")));
         $this->writeln($this->red($error));
         $this->writeln();
         $this->writeln($this->red('===================='));
@@ -242,12 +245,11 @@ class Horde_CLI {
     /**
      * Prompts for a user response.
      *
-     * @param string $prompt            The message to display when
-     *                                  prompting the user.
-     * @param optional array $choices   The choices available to the
-     *                                  user or null for a text input.
+     * @param string $prompt  The message to display when prompting the user.
+     * @param array $choices  The choices available to the user or null for a
+     *                        text input.
      *
-     * @return mixed   The user's response to the prompt.
+     * @return mixed  The user's response to the prompt.
      */
     function prompt($prompt, $choices = null)
     {
@@ -267,7 +269,7 @@ class Horde_CLI {
                 if (isset($choices[$response])) {
                     return $response;
                 } else {
-                    $this->writeln(sprintf(_("'%s' is not a valid choice."), $response));
+                    $this->writeln(sprintf(_("\"%s\" is not a valid choice."), $response));
                 }
             } else {
                 return trim(fgets(STDIN));
@@ -297,7 +299,7 @@ class Horde_CLI {
      * none. Also initialize a few variables in $_SERVER that aren't
      * present from the CLI.
      *
-     * @access static
+     * @static
      */
     function init()
     {
@@ -315,7 +317,7 @@ class Horde_CLI {
      * Make sure we're being called from the command line, and not via
      * the web.
      *
-     * @access static
+     * @static
      *
      * @return boolean  True if we are, false otherwise.
      */
