@@ -3,15 +3,14 @@
  * The Horde_Form_Renderer class provides HTML and other renderings of
  * forms for the Horde_Form:: package.
  *
- * $Horde: framework/Form/Form/Renderer.php,v 1.185.4.1 2004/12/22 22:07:53 jan Exp $
+ * $Horde: framework/Form/Form/Renderer.php,v 1.185.4.9 2005/06/23 19:59:43 selsky Exp $
  *
- * Copyright 2001-2004 Robert E. Coyle <robertecoyle@hotmail.com>
+ * Copyright 2001-2005 Robert E. Coyle <robertecoyle@hotmail.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Robert E. Coyle <robertecoyle@hotmail.com>
- * @version $Revision: 1.185.4.1 $
  * @package Horde_Form
  */
 class Horde_Form_Renderer {
@@ -19,6 +18,7 @@ class Horde_Form_Renderer {
     var $_name;
     var $_requiredLegend = false;
     var $_requiredMarker = '*';
+    var $_helpMarker = '?';
     var $_onLoadJS = array();
     var $_showHeader = true;
     var $_cols = 2;
@@ -30,7 +30,7 @@ class Horde_Form_Renderer {
      * doing any needed escaping/sanitization yourself. Otherwise the title
      * will be run through htmlspecialchars() before being output.
      *
-     * @var boolean $_encodeTitle
+     * @var boolean
      */
     var $_encodeTitle = true;
 
@@ -38,7 +38,7 @@ class Horde_Form_Renderer {
      * Width of the attributes column.
      *
      * @access private
-     * @var string $_attrColumnWidth
+     * @var string
      */
     var $_attrColumnWidth = '15%';
 
@@ -49,7 +49,7 @@ class Horde_Form_Renderer {
      *                       Possible keys:<code>
      *                       'varrenderer_driver': specifies the driver
      *                           parameter to Horde_UI_VarRenderer::factory().
-     *                       'encode_title': @see $_encodeTitle
+     *                       'encode_title': @see $_encodeTitle</code>
      */
     function Horde_Form_Renderer($params = array())
     {
@@ -135,54 +135,47 @@ class Horde_Form_Renderer {
 
         $open_section = $form->getOpenSection();
 
+        /* Print out the tabs for all the sections. */
+        echo '<table cellspacing="0"><tr valign="bottom"><td colspan="' .
+            $this->_cols . '">';
+
         /* Add the javascript for the toggling the sections. */
         Horde::addScriptFile('form_sections.js', 'horde');
-        $js  = '<script language="JavaScript" type="text/javascript">' . "\n";
-        $js .= sprintf('var sections_%1$s = new Horde_Form_Sections(\'%1$s\', \'%2$s\');',
-                       $form->getName(),
-                       $open_section);
-        $js .= "\n" . '</script>';
-
-        echo $js;
-
-        /* Print out the tabs for all the sections. */
-        printf('<tr valign="bottom"><td colspan="%s"><ul class="tabset">', $this->_cols);
+        echo '<script language="JavaScript" type="text/javascript">' . "\n";
+        echo sprintf('var sections_%1$s = new Horde_Form_Sections(\'%1$s\', \'%2$s\');',
+                     $form->getName(),
+                     $open_section);
+        echo "\n" . '</script>';
 
         /* Loop through the sections and print out a tab for each. */
+        echo "<ul class=\"tabset\">\n";
         foreach ($form->_sections as $section => $val) {
             $class = ($section == $open_section) ? ' class="activeTab"' : '';
             $js = sprintf('onclick="sections_%s.toggle(\'%s\'); return false;"',
                           $form->getName(),
                           $section);
-            printf('<li><a id="_tab_' . $section . '"' . $class . '" href="#" %s>%s%s</a> </li>',
+            printf('<li><a id="_tab_' . $section . '"' . $class . '" href="#" %s>%s%s</a> </li>' . "\n",
                    $js,
                    $form->getSectionImage($section),
                    str_replace(' ', '&nbsp;', $form->getSectionDesc($section)));
         }
-
-        echo '</ul></td></tr>';
+        echo "</ul></td></tr></table>\n";
     }
 
     function _renderSectionBegin(&$form, $section)
     {
-        static $first_section = '';
-
-        if (empty($first_section)) {
-            /* If this is the first section being rendered, set it as
-             * open and and render the section tabs. */
-            $first_section = $section;
-            $this->_renderSectionTabs($form);
-        }
-
         $open_section = $form->getOpenSection();
-        printf('</table><div id="%s" style="display:%s;"><table class="item" cellspacing="0">',
+        if (empty($open_section)) {
+            $open_section = '__base';
+        }
+        printf('<div id="%s" style="display:%s;"><table class="item" cellspacing="0">',
                '_section_' . $section,
                ($open_section == $section ? 'block' : 'none'));
     }
 
     function _renderSectionEnd()
     {
-        echo '</table></div><table cellspacing="0">';
+        echo '</table></div>';
     }
 
     function end()
@@ -250,10 +243,13 @@ try {
         }
 
         $error_section = null;
+        reset($variables);
+        if (count($variables) > 1 || key($variables) != '__base') {
+            $this->_renderSectionTabs($form);
+        }
+
         foreach ($variables as $section_id => $section) {
-            if ($section_id != '__base') {
-                $this->_renderSectionBegin($form, $section_id);
-            }
+            $this->_renderSectionBegin($form, $section_id);
             foreach ($section as $var) {
                 $type = $var->getTypeName();
 
@@ -298,9 +294,7 @@ try {
                 }
             }
 
-            if ($section_id != '__base') {
-                $this->_renderSectionEnd();
-            }
+            $this->_renderSectionEnd();
         }
 
         if (!is_null($error_section)) {
@@ -330,10 +324,9 @@ try {
         if ($this->_showHeader) {
             $this->_sectionHeader($name, $extra);
         }
-        echo '<table cellspacing="0">';
-        if ($this->_requiredLegend): ?>
-<tr><td></td><td><span class="form-error"><?php echo $this->_requiredMarker ?></span> = Required Field</td></tr>
-<?php endif;
+        if ($this->_requiredLegend) {
+            echo '<span class="form-error">' . $this->_requiredMarker . '</span> = ' . _("Required Field");
+        }
     }
 
     function _renderBeginInactive($name, $extra)
@@ -342,13 +335,11 @@ try {
         if ($this->_showHeader) {
             $this->_sectionHeader($name, $extra);
         }
-        echo '<table cellspacing="0">';
     }
 
     function _renderEnd()
     {
-        echo '</table></div>';
-        echo $this->_varRenderer->renderEnd();
+        echo '</div>' . $this->_varRenderer->renderEnd();
     }
 
     function _renderHeader($header, $error = '')
@@ -375,14 +366,14 @@ try {
 
     function _renderSubmit($submit, $reset)
     {
-?><tr><td colspan="<?php echo $this->_cols; ?>" class="control">
+?><table cellspacing="0"><tr><td colspan="<?php echo $this->_cols; ?>" class="control">
   <?php if (!is_array($submit)) $submit = array($submit); foreach ($submit as $submitbutton): ?>
     <input class="button" name="submitbutton" type="submit" value="<?php echo $submitbutton ?>" />
   <?php endforeach; ?>
   <?php if (!empty($reset)): ?>
     <input class="button" name="resetbutton" type="reset" value="<?php echo $reset ?>" />
   <?php endif; ?>
-</td></tr>
+</td></tr></table>
 <?php
     }
 
@@ -414,8 +405,14 @@ try {
 
         /* Display any help for the field. */
         if ($var->hasHelp()) {
+            global $registry;
+            if (isset($registry) && is_a($registry, 'Registry')) {
+                $link = Help::link($GLOBALS['registry']->getApp(), $var->getHelp());
+            } else {
+                $link = '<a href="#" onclick="alert(\'' . addslashes(@htmlspecialchars($var->getHelp())) . '\');return false;">' . $this->_helpMarker . '</a>';
+            }
             $class = $this->getRowClass(false);
-            echo "</td>\n  <td align=\"right\" class=\"" . $class . '">' . Help::link($GLOBALS['registry']->getApp(), $var->getHelp()) . '&nbsp';
+            echo "</td>\n  <td align=\"right\" class=\"" . $class . '">' . $link . '&nbsp;';
         }
 
         echo "</td>\n</tr>\n";
@@ -466,18 +463,19 @@ try {
     }
 
     /**
-     * Attempts to return a concrete Horde_Form_Renderer instance
-     * based on $renderer.
+     * Attempts to return a concrete Horde_Form_Renderer instance based on
+     * $renderer.
      *
-     * @param mixed $renderer  The type of concrete Horde_Form_Renderer subclass to return.
-     *                         The code is dynamically included. If $renderer is an array,
-     *                         then we will look in $renderer[0]/lib/Form/Renderer/ for
-     *                         the subclass implementation named $renderer[1].php.
-     * @param array $params    (optional) A hash containing any additional
-     *                         configuration a form might need.
+     * @param mixed $renderer  The type of concrete Horde_Form_Renderer
+     *                         subclass to return. The code is dynamically
+     *                         included. If $renderer is an array, then we will
+     *                         look in $renderer[0]/lib/Form/Renderer/ for the
+     *                         subclass implementation named $renderer[1].php.
+     * @param array $params    A hash containing any additional configuration a
+     *                         form might need.
      *
-     * @return object Horde_Form_Renderer  The concrete Horde_Form_Renderer reference,
-     *                                     or false on an error.
+     * @return Horde_Form_Renderer  The concrete Horde_Form_Renderer reference,
+     *                              or false on an error.
      */
     function &factory($renderer, $params = null)
     {
@@ -518,18 +516,16 @@ try {
      *
      * This method must be invoked as: $var = &Horde_Form_Renderer::singleton()
      *
-     * @param mixed $renderer         The type of concrete Horde_Form_Renderer
-     *                                subclass to return. The code is
-     *                                dynamically included. If $renderer is an
-     *                                array, then we will look in
-     *                                $renderer[0]/lib/Form/Renderer/ for the
-     *                                subclass implementation named
-     *                                $renderer[1].php.
-     * @param optional array $params  A hash containing any additional
-     *                                configuration a form might need.
+     * @param mixed $renderer  The type of concrete Horde_Form_Renderer
+     *                         subclass to return. The code is dynamically
+     *                         included. If $renderer is an array, then we will
+     *                         look in $renderer[0]/lib/Form/Renderer/ for the
+     *                         subclass implementation named $renderer[1].php.
+     * @param array $params  A hash containing any additional configuration a
+     *                       form might need.
      *
-     * @return object Horde_Form_Renderer  The concrete Horde_Form_Renderer
-     *                                     reference, or false on an error.
+     * @return Horde_Form_Renderer  The concrete Horde_Form_Renderer reference,
+     *                              or false on an error.
      */
     function &singleton($renderer, $params = null)
     {
