@@ -3,24 +3,21 @@
  * Contains functions related to managing Access Control Lists on an IMAP
  * server using RFC 2086.
  *
- * <pre>
- * Required parameters:
- * ====================
- *  'username'  --  The username for the server connection
- *  'password'  --  The password for the server connection
- *  'hostspec'  --  The hostname or IP address of the server.
- *                  DEFAULT: 'localhost'
- *  'port'      --  The server port to which we will connect.
- *                  IMAP is generally 143, while IMAP-SSL is generally 993.
- *                  DEFAULT: 143
- *  'protocol'  --  The connection protocol (e.g. 'imap', 'pop3', 'nntp').
- *                  Protocol is one of 'imap/notls' (or only 'imap' if you
- *                  have a c-client version 2000c or older), 'imap/ssl', or
- *                  'imap/ssl/novalidate-cert' (for a self-signed certificate).
- *                  DEFAULT: 'imap'
- * </pre>
+ * Required parameters:<pre>
+ *   'username'  The username for the server connection
+ *   'password'  The password for the server connection
+ *   'hostspec'  The hostname or IP address of the server.
+ *               DEFAULT: 'localhost'
+ *   'port'      The server port to which we will connect.
+ *               IMAP is generally 143, while IMAP-SSL is generally 993.
+ *               DEFAULT: 143
+ *   'protocol'  The connection protocol (e.g. 'imap', 'pop3', 'nntp').
+ *               Protocol is one of 'imap/notls' (or only 'imap' if you
+ *               have a c-client version 2000c or older), 'imap/ssl', or
+ *               'imap/ssl/novalidate-cert' (for a self-signed certificate).
+ *               DEFAULT: 'imap'</pre>
  *
- * $Horde: framework/IMAP/IMAP/ACL/rfc2086.php,v 1.6.8.2 2005/03/08 09:15:04 jan Exp $
+ * $Horde: framework/IMAP/IMAP/ACL/rfc2086.php,v 1.6.8.6 2005/08/24 14:04:36 selsky Exp $
  *
  * Copyright 2003-2005 Chris Hastie <imp@oak-wood.co.uk>
  *
@@ -35,6 +32,8 @@ class IMAP_ACL_rfc2086 extends IMAP_ACL {
 
     /**
      * IMAP resource.
+     *
+     * @var resource
      */
     var $_imap;
 
@@ -47,15 +46,13 @@ class IMAP_ACL_rfc2086 extends IMAP_ACL {
      * )
      * </code>
      *
-     * @var array $_caps
+     * @var array
      */
     var $_caps = array();
 
     /**
      * Constructor.
      *
-     * @access public
-     *
      * @param array $params  Any additional parameters this driver may need.
      */
     function IMAP_ACL_rfc2086($params = array())
@@ -117,8 +114,6 @@ class IMAP_ACL_rfc2086 extends IMAP_ACL {
     /**
      * Sets the ACL on an IMAP server.
      *
-     * @access public
-     *
      * @param string $folder      The folder on which to edit the ACL.
      * @param string $share_user  The user to grant rights to.
      * @param array $acl          An array, the keys of which are the rights to
@@ -156,7 +151,7 @@ class IMAP_ACL_rfc2086 extends IMAP_ACL {
                 }
                 return PEAR::raiseError($error_string);
             }
-            return PEAR::raiseError(sprintf(_("Couldn't give user '%s' the following rights for the folder '%s': %s"), $share_user, $folder, $acl_str));
+            return PEAR::raiseError(sprintf(_("Couldn't give user \"%s\" the following rights for the folder \"%s\": %s"), $share_user, $folder, $acl_str));
         }
 
         return $result;
@@ -165,8 +160,6 @@ class IMAP_ACL_rfc2086 extends IMAP_ACL {
     /**
      * Edits an ACL on an IMAP server.
      *
-     * @access public
-     *
      * @param string $folder      The folder on which to edit the ACL.
      * @param string $share_user  The user to grant rights to.
      * @param array $acl          An array, the keys of which are the rights to
@@ -239,8 +232,6 @@ class IMAP_ACL_rfc2086 extends IMAP_ACL {
      * Attempts to retrieve the existing ACL for a folder from the current
      * IMAP server.
      *
-     * @access public
-     *
      * @param string folder  The folder to get the ACL for.
      *
      * @return array  A hash containing information on the ACL.
@@ -408,8 +399,6 @@ class IMAP_ACL_rfc2086 extends IMAP_ACL {
     /**
      * Can a user edit the ACL for this folder?
      *
-     * @access public
-     *
      * @param string $folder  The folder name.
      * @param string $user    A user name.
      *
