@@ -3,7 +3,7 @@
  * The MIME_Viewer_rpm class renders out lists of files in RPM
  * packages by using the rpm tool to query the package.
  *
- * $Horde: framework/MIME/MIME/Viewer/rpm.php,v 1.12.10.1 2005/01/03 12:19:06 jan Exp $
+ * $Horde: framework/MIME/MIME/Viewer/rpm.php,v 1.12.10.5 2005/07/03 05:04:10 selsky Exp $
  *
  * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
  *
@@ -11,7 +11,6 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.12.10.1 $
  * @since   Horde 1.3
  * @package Horde_MIME_Viewer
  */
@@ -20,9 +19,7 @@ class MIME_Viewer_rpm extends MIME_Viewer {
     /**
      * Render out the RPM contents.
      *
-     * @access public
-     *
-     * @param optional array $params  Any parameters the Viewer may need.
+     * @param array $params  Any parameters the Viewer may need.
      *
      * @return string  The rendered contents.
      */
@@ -54,13 +51,11 @@ class MIME_Viewer_rpm extends MIME_Viewer {
     /**
      * Return the MIME content type of the rendered content.
      *
-     * @access public
-     *
      * @return string  The content type of the output. 
      */
     function getType()
     {
-        return 'text/html';
+        return 'text/html; charset=' . NLS::getCharset();
     }
 
 }
