@@ -11,11 +11,11 @@ define('HORDE_SESSION_READONLY', 2);
  * between Horde applications and keeping track of application
  * configuration information.
  *
- * $Horde: framework/Horde/Horde/Registry.php,v 1.243 2004/12/21 19:35:57 chuck Exp $
+ * $Horde: framework/Horde/Horde/Registry.php,v 1.243.2.11.2.2 2005/10/27 11:08:41 jan Exp $
  *
- * Copyright 1999-2004 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 1999-2004 Jon Parise <jon@horde.org>
- * Copyright 1999-2004 Anil Madhavapeddy <anil@recoil.org>
+ * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2005 Jon Parise <jon@horde.org>
+ * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -23,7 +23,6 @@ define('HORDE_SESSION_READONLY', 2);
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.243 $
  * @since   Horde 1.3
  * @package Horde_Framework
  */
@@ -32,14 +31,14 @@ class Registry {
     /**
      * Hash storing all of the known services and callbacks.
      *
-     * @var array $_apiCache
+     * @var array
      */
     var $_apiCache = array();
 
     /**
      * Hash storing all known data types.
      *
-     * @var array $_typeCache
+     * @var array
      */
     var $_typeCache = array();
 
@@ -47,42 +46,42 @@ class Registry {
      * Hash storing all of the registered interfaces that applications
      * provide.
      *
-     * @var array $_interfaces
+     * @var array
      */
     var $_interfaces = array();
 
     /**
      * Hash storing information on each registry-aware application.
      *
-     * @var array $applications
+     * @var array
      */
     var $applications = array();
 
     /**
      * Stack of in-use applications.
      *
-     * @var array $_appStack
+     * @var array
      */
     var $_appStack = array();
 
     /**
      * Quick pointer to the current application.
      *
-     * @var $_currentApp
+     * @var string
      */
     var $_currentApp = null;
 
     /**
      * Cache of $prefs objects
      *
-     * @var array $_prefsCache
+     * @var array
      */
     var $_prefsCache = array();
 
     /**
      * Cache of application configurations.
      *
-     * @var array $_confCache
+     * @var array
      */
     var $_confCache = array();
 
@@ -92,9 +91,9 @@ class Registry {
      *
      * This method must be invoked as: $registry = &Registry::singleton()
      *
-     * @param optional integer $session_flags  Any session flags.
+     * @param integer $session_flags  Any session flags.
      *
-     * @return object Registry  The Horde Registry instance.
+     * @return Registry  The Horde Registry instance.
      */
     function &singleton($session_flags = 0)
     {
@@ -111,7 +110,7 @@ class Registry {
      * Create a new registry instance. Should never be called except
      * by &Registry::singleton().
      *
-     * @param optional integer $session_flags  Any session flags.
+     * @param integer $session_flags  Any session flags.
      *
      * @access private
      */
@@ -202,13 +201,11 @@ class Registry {
      *
      * @since Horde 2.2
      *
-     * @access public
-     *
-     * @param optional array   $filter      An array of the statuses that should be
-     *                                      returned. Defaults to non-hidden.
-     * @param optional boolean $assoc       Associative array with app names as keys.
-     * @param optional integer $permission  The permission level to check for in the list.
-     *                                      Defaults to PERMS_SHOW.
+     * @param array   $filter      An array of the statuses that should be
+     *                             returned. Defaults to non-hidden.
+     * @param boolean $assoc       Associative array with app names as keys.
+     * @param integer $permission  The permission level to check for in the
+     *                             list. Defaults to PERMS_SHOW.
      *
      * @return array  List of apps registered with Horde. If no
      *                applications are defined returns an empty array.
@@ -233,8 +230,6 @@ class Registry {
     /**
      * Returns all available registry APIs.
      *
-     * @access public
-     *
      * @return array  The API list.
      */
     function listAPIs()
@@ -253,10 +248,8 @@ class Registry {
      * Returns all of the available registry methods, or alternately
      * only those for a specified API.
      *
-     * @access public
-     *
-     * @param optional string $api  Defines the API for which the methods
-     *                              shall be returned.
+     * @param string $api  Defines the API for which the methods shall be
+     *                     returned.
      *
      * @return array  The method list.
      */
@@ -298,8 +291,6 @@ class Registry {
     /**
      * Returns all of the available registry data types.
      *
-     * @access public
-     *
      * @return array  The data type list.
      */
     function listTypes()
@@ -311,8 +302,6 @@ class Registry {
     /**
      * Returns a method's signature.
      *
-     * @access public
-     *
      * @param string $method  The full name of the method to check for.
      *
      * @return array  A two dimensional array. The first element contains an
@@ -335,10 +324,7 @@ class Registry {
     }
 
     /**
-     * Determine if an interface is implemented by an active
-     * application.
-     *
-     * @access public
+     * Determine if an interface is implemented by an active application.
      *
      * @param string $interface  The interface to check for.
      *
@@ -355,10 +341,8 @@ class Registry {
     /**
      * Determine if a method has been registered with the registry.
      *
-     * @access public
-     *
-     * @param string $method        The full name of the method to check for.
-     * @param optional string $app  Only check this application.
+     * @param string $method  The full name of the method to check for.
+     * @param string $app     Only check this application.
      *
      * @return mixed  The application implementing $method if we have it,
      *                false if the method doesn't exist.
@@ -389,10 +373,8 @@ class Registry {
      * parameter. $method is a string consisting of
      * "packagetype/methodname".
      *
-     * @access public
-     *
-     * @param string $method        The method to call.
-     * @param optional array $args  Arguments to the method.
+     * @param string $method  The method to call.
+     * @param array $args     Arguments to the method.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -415,11 +397,9 @@ class Registry {
     /**
      * Output the hook corresponding to the specific package named.
      *
-     * @access public
-     *
-     * @param string $app           The application being called.
-     * @param string $call          The method to call.
-     * @param optional array $args  Arguments to the method.
+     * @param string $app   The application being called.
+     * @param string $call  The method to call.
+     * @param array $args   Arguments to the method.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -467,12 +447,9 @@ class Registry {
      * parameter. $method is a string consisting of
      * "packagetype/methodname".
      *
-     * @access public
-     *
-     * @param string $method         The method to link to.
-     * @param optional array $args   Arguments to the method.
-     * @param optional mixed $extra  Extra, non-standard arguments to the
-     *                               method.
+     * @param string $method  The method to link to.
+     * @param array $args     Arguments to the method.
+     * @param mixed $extra    Extra, non-standard arguments to the method.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -495,13 +472,10 @@ class Registry {
     /**
      * Output the hook corresponding to the specific package named.
      *
-     * @access public
-     *
-     * @param string $app            The application being called.
-     * @param string $call           The method to link to.
-     * @param optional array $args   Arguments to the method.
-     * @param optional mixed $extra  Extra, non-standard arguments to the
-     *                               method.
+     * @param string $app   The application being called.
+     * @param string $call  The method to link to.
+     * @param array $args   Arguments to the method.
+     * @param mixed $extra  Extra, non-standard arguments to the method.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -561,13 +535,11 @@ class Registry {
     }
 
     /**
-     * Replace any %application% strings with the filesystem path to
-     * the application.
+     * Replace any %application% strings with the filesystem path to the
+     * application.
      *
-     * @access public
-     *
-     * @param string $path          The application string.
-     * @param optional string $app  The application being called.
+     * @param string $path  The application string.
+     * @param string $app   The application being called.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -579,20 +551,17 @@ class Registry {
         }
 
         if (!isset($this->applications[$app])) {
-            return PEAR::raiseError(sprintf(_("'%s' is not configured in the Horde Registry."), $app));
+            return PEAR::raiseError(sprintf(_("\"%s\" is not configured in the Horde Registry."), $app));
         }
 
         return str_replace('%application%', $this->applications[$app]['fileroot'], $path);
     }
 
     /**
-     * Replace any %application% strings with the web path to the
-     * application.
+     * Replace any %application% strings with the web path to the application.
      *
-     * @access public
-     *
-     * @param string $path          The application string.
-     * @param optional string $app  The application being called.
+     * @param string $path  The application string.
+     * @param string $app   The application being called.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -614,14 +583,12 @@ class Registry {
      * pushApp() also reads the application's configuration file and
      * sets up its global $conf hash.
      *
-     * @access public
-     *
      * @param string  $app         The name of the application to push.
      * @param boolean $checkPerms  Make sure that the current user has
-     *                             permissions to the application being
-     *                             loaded. Defaults to true. Should ONLY
-     *                             be disabled by system scripts (cron jobs,
-     *                             etc.) and scripts that handle login.
+     *                             permissions to the application being loaded
+     *                             Defaults to true. Should ONLY be disabled by
+     *                             system scripts (cron jobs, etc.) and scripts
+     *                             that handle login.
      *
      * @return boolean  Whether or not the _appStack was modified.
      *                  Return PEAR_Error on error.
@@ -674,18 +641,15 @@ class Registry {
 
         /* Once we know everything succeeded and is in a consistent
          * state again, push the new application onto the stack. */
-        array_push($this->_appStack, $app);
+        $this->_appStack[] = $app;
         $this->_currentApp = $app;
 
         return true;
     }
 
     /**
-     * Remove the current app from the application stack, setting the
-     * current app to whichever app was current before this one took
-     * over.
-     *
-     * @access public
+     * Remove the current app from the application stack, setting the current
+     * app to whichever app was current before this one took over.
      *
      * @return string  The name of the application that was popped.
      */
@@ -712,10 +676,8 @@ class Registry {
     }
 
     /**
-     * Return the current application - the app at the top of the
-     * application stack.
-     *
-     * @access public
+     * Return the current application - the app at the top of the application
+     * stack.
      *
      * @return string  The current application.
      */
@@ -727,22 +689,19 @@ class Registry {
     /**
      * Check permissions on an application.
      *
-     * @access public
-     *
      * @return boolean  Whether or not access is allowed.
      */
     function hasPermission($app, $permission = PERMS_READ)
     {
-        return Auth::isAdmin() || ($GLOBALS['perms']->exists($app) ?
-                                   $GLOBALS['perms']->hasPermission($app, Auth::getAuth(), $permission) :
-                                   (bool)Auth::getAuth());
+        return Auth::isAdmin() ||
+            ($GLOBALS['perms']->exists($app)
+             ? $GLOBALS['perms']->hasPermission($app, Auth::getAuth(), $permission)
+             : (bool)Auth::getAuth());
     }
 
     /**
-     * Reads the configuration values for the given application and
-     * imports them into the global $conf variable.
-     *
-     * @access public
+     * Reads the configuration values for the given application and imports
+     * them into the global $conf variable.
      *
      * @param string $app  The name of the application.
      *
@@ -758,7 +717,13 @@ class Registry {
         if (!isset($this->_confCache[$app])) {
             if (!isset($this->_confCache['horde'])) {
                 $conf = array();
-                $success = @include HORDE_BASE . '/config/conf.php';
+                ob_start();
+                $success = include HORDE_BASE . '/config/conf.php';
+                $errors = ob_get_contents();
+                ob_end_clean();
+                if (!empty($errors)) {
+                    return PEAR::raiseError(sprintf('Failed to import Horde configuration: %s', strip_tags($errors)));
+                }
                 if (!$success) {
                     return PEAR::raiseError('Failed to import Horde configuration.');
                 }
@@ -796,10 +761,8 @@ class Registry {
     }
 
     /**
-     * Loads the preferences for the current user for the current
-     * application and imports them into the global $prefs variable.
-     *
-     * @access public
+     * Loads the preferences for the current user for the current application
+     * and imports them into the global $prefs variable.
      *
      * @param string $app  The name of the application.
      */
@@ -845,10 +808,8 @@ class Registry {
      * After unloading, if there is an application on the app stack to
      * load preferences from, then we reload a fresh set.
      *
-     * @access public
-     *
-     * @param string $app  (optional) The application to unload prefrences for.
-     *                     If null, ALL preferences are reset.
+     * @param string $app  The application to unload prefrences for. If null,
+     *                     ALL preferences are reset.
      */
     function unloadPrefs($app = null)
     {
@@ -873,10 +834,8 @@ class Registry {
      * Horde-wide value is used instead. If that is not present, we
      * return null.
      *
-     * @access public
-     *
-     * @param string $parameter     The configuration value to retrieve.
-     * @param optional string $app  The application to get the value for.
+     * @param string $parameter  The configuration value to retrieve.
+     * @param string $app        The application to get the value for.
      *
      * @return string  The requested parameter, or null if it is not set.
      */
@@ -904,14 +863,12 @@ class Registry {
     }
 
     /**
-     * Function to work out an application's graphics URI, taking into
-     * account any themes directories that may be set up.
+     * Function to work out an application's graphics URI, taking into account
+     * any themes directories that may be set up.
      *
-     * @access public
-     *
-     * @param optional string $app  The application for which to get the
-     *                              image directory. If blank will default
-     *                              to current application.
+     * @param string $app  The application for which to get the image
+     *                     directory. If blank will default to current
+     *                     application.
      *
      * @return string  The image directory uri path.
      */
@@ -929,11 +886,15 @@ class Registry {
         /* This is the default location for the graphics. */
         $img_dir[$app] = $this->get('themesuri', $app) . '/graphics';
 
+        static $theme_icons;
+
         /* Figure out if this is going to be overridden by any theme
          * settings. */
-        if (isset($GLOBALS['prefs']) && ($theme = $GLOBALS['prefs']->getValue('theme')) &&
-            (@include $this->get('themesfs', 'horde') . '/' . $theme . '/info.php') &&
-            isset($theme_icons) &&
+        if (isset($GLOBALS['prefs']) &&
+            ($theme = $GLOBALS['prefs']->getValue('theme')) &&
+            (isset($theme_icons) ||
+             ((@include $this->get('themesfs', 'horde') . '/' . $theme . '/info.php') &&
+              isset($theme_icons))) &&
             in_array($app, $theme_icons)) {
             $img_dir[$app] = $this->get('themesuri', $app) . '/' . $theme . '/graphics';
         }
@@ -955,13 +916,10 @@ class Registry {
     }
 
     /**
-     * Query the initial page for an application - the webroot, if
-     * there is no initial_page set, and the initial_page, if it is
-     * set.
+     * Query the initial page for an application - the webroot, if there is no
+     * initial_page set, and the initial_page, if it is set.
      *
-     * @access public
-     *
-     * @param optional string $app  The name of the application.
+     * @param string $app  The name of the application.
      *
      * @return string  URL pointing to the inital page of the application.
      *                 Returns PEAR_Error on error.
@@ -973,7 +931,7 @@ class Registry {
         }
 
         if (!isset($this->applications[$app])) {
-            return PEAR::raiseError(sprintf(_("'%s' is not configured in the Horde Registry."), $app));
+            return PEAR::raiseError(sprintf(_("\"%s\" is not configured in the Horde Registry."), $app));
         }
         return $this->applications[$app]['webroot'] . '/' . (isset($this->applications[$app]['initial_page']) ? $this->applications[$app]['initial_page'] : '');
     }
