@@ -5,7 +5,7 @@
  *
  * No additional configuration parameters needed.
  *
- * $Horde: framework/SessionHandler/SessionHandler/dbm.php,v 1.9.12.1 2005/01/03 12:19:13 jan Exp $
+ * $Horde: framework/SessionHandler/SessionHandler/dbm.php,v 1.9.12.5 2005/06/26 04:28:31 chuck Exp $
  *
  * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -13,7 +13,6 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.9.12.1 $
  * @since   Horde 3.0
  * @package Horde_SessionHandler
  */
@@ -22,23 +21,17 @@ class SessionHandler_dbm extends SessionHandler {
     /**
      * Our pointer to the DBM file, if open.
      *
-     * @var resource $_dbm
+     * @var resource
      */
     var $_dbm;
 
     /**
-     * Constructs a new DBM SessionHandler object.
+     * Open the SessionHandler backend.
      *
-     * @access public
+     * @param string $save_path     The path to the session object.
+     * @param string $session_name  The name of the session.
      *
-     * @param optional array $params  [Unused].
-     */
-    function SessionHandler_dbm($params = array())
-    {
-    }
-
-    /**
-     * TODO
+     * @return boolean  True on success, false otherwise.
      */
     function open($save_path, $session_name)
     {
@@ -47,7 +40,9 @@ class SessionHandler_dbm extends SessionHandler {
     }
 
     /**
-     * TODO
+     * Close the SessionHandler backend.
+     *
+     * @return boolean  True on success, false otherwise.
      */
     function close()
     {
@@ -55,7 +50,12 @@ class SessionHandler_dbm extends SessionHandler {
     }
 
     /**
-     * TODO
+     * Read the data for a particular session identifier from the
+     * SessionHandler backend.
+     *
+     * @param string $id  The session identifier.
+     *
+     * @return string  The session data.
      */
     function read($id)
     {
@@ -67,7 +67,12 @@ class SessionHandler_dbm extends SessionHandler {
     }
 
     /**
-     * TODO
+     * Write session data to the SessionHandler backend.
+     *
+     * @param string $id            The session identifier.
+     * @param string $session_data  The session data.
+     *
+     * @return boolean  True on success, false otherwise.
      */
     function write($id, $session_data)
     {
@@ -75,7 +80,12 @@ class SessionHandler_dbm extends SessionHandler {
     }
 
     /**
-     * TODO
+     * Destroy the data for a particular session identifier in the
+     * SessionHandler backend.
+     *
+     * @param string $id  The session identifier.
+     *
+     * @return boolean  True on success, false otherwise.
      */
     function destroy($id)
     {
@@ -88,9 +98,13 @@ class SessionHandler_dbm extends SessionHandler {
     }
 
     /**
-     * TODO
+     * Garbage collect stale sessions from the SessionHandler backend.
+     *
+     * @param integer $maxlifetime  The maximum age of a session.
+     *
+     * @return boolean  True on success, false otherwise.
      */
-    function gc($maxlifetime = 300) 
+    function gc($maxlifetime = 300)
     {
         $expired = time() - $maxlifetime;
         $id = dbmfirstkey($this->_dbm);
