@@ -4,7 +4,7 @@
  * (usually, but not necessarily, objects) in the current user's
  * session.
  *
- * $Horde: framework/SessionObjects/SessionObjects.php,v 1.6.12.1 2005/01/03 12:19:14 jan Exp $
+ * $Horde: framework/SessionObjects/SessionObjects.php,v 1.6.12.6 2005/07/11 17:10:36 jan Exp $
  *
  * Copyright 2003-2005 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -12,7 +12,6 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.6.12.1 $
  * @since   Horde 1.3
  * @package Horde_SessionObjects
  */
@@ -21,28 +20,28 @@ class Horde_SessionObjects {
     /**
      * The list of oids to prune at the end of a request.
      *
-     * @var array $_pruneList
+     * @var array
      */
     var $_pruneList = null;
 
     /**
      * The name of the store.
      *
-     * @var string $_name
+     * @var string
      */
     var $_name = 'horde_session_objects';
 
     /**
      * Allow store() to overwrite current objects?
      *
-     * @var boolean $_overwrite
+     * @var boolean
      */
     var $_overwrite = false;
 
     /**
      * The maximum number of objects that the store should hold.
      * 
-     * @var integer $size
+     * @var integer
      */
     var $_size = 20;
 
@@ -53,9 +52,7 @@ class Horde_SessionObjects {
      * This method must be invoked as:
      *   $objectstore = &Horde_SessionObjects::singleton();
      *
-     * @access public
-     *
-     * @return object Horde_SessionObjects  The Horde_SessionObjects instance.
+     * @return Horde_SessionObjects  The Horde_SessionObjects instance.
      */
     function &singleton()
     {
@@ -71,9 +68,7 @@ class Horde_SessionObjects {
     /**
      * Constructor.
      *
-     * @access public
-     *
-     * @param optional array $params  The parameter array.
+     * @param array $params  The parameter array.
      * <pre>
      * Optional Parameters:
      * 'name'  --  The name of the session variable to store the objects in.
@@ -96,13 +91,9 @@ class Horde_SessionObjects {
      *
      * @see store
      *
-     * @access public
-     *
-     * @param mixed $data              The data to store in the session
-     *                                 store.
-     * @param optional boolean $prune  If false, this object will not be
-     *                                 pruned from the store if the maximum
-     *                                 store size is exceeded.
+     * @param mixed $data     The data to store in the session store.
+     * @param boolean $prune  If false, this object will not be pruned from the
+     *                        store if the maximum store size is exceeded.
      *
      * @return string  The MD5 string representing the object's ID.
      */
@@ -116,14 +107,10 @@ class Horde_SessionObjects {
     /**
      * Attempts to store an object in the session store.
      *
-     * @access public
-     *
-     * @param string $oid              Object ID used as the storage key.
-     * @param mixed $data              The data to store in the session
-     *                                 store.
-     * @param optional boolean $prune  If false, this object will not be
-     *                                 pruned from the store if the maximum
-     *                                 store size is exceeded.
+     * @param string $oid     Object ID used as the storage key.
+     * @param mixed $data     The data to store in the session store.
+     * @param boolean $prune  If false, this object will not be pruned from the
+     *                        store if the maximum store size is exceeded.
      *
      * @return boolean  True on success, false on failure.
      */
@@ -155,14 +142,10 @@ class Horde_SessionObjects {
     /**
      * Overwrites a current element in the object store.
      *
-     * @access public
-     *
-     * @param string $oid              Object ID used as the storage key.
-     * @param mixed $data              The data to store in the session
-     *                                 store.
-     * @param optional boolean $prune  If false, this object will not be
-     *                                 pruned from the store if the maximum
-     *                                 store size is exceeded.
+     * @param string $oid     Object ID used as the storage key.
+     * @param mixed $data     The data to store in the session store.
+     * @param boolean $prune  If false, this object will not be pruned from the
+     *                        store if the maximum store size is exceeded.
      *
      * @return boolean  True on success, false on failure.
      */
@@ -173,32 +156,30 @@ class Horde_SessionObjects {
         $this->_overwrite = false;
         return $success;
     }
+
     /**
      * Attempts to retrive an object from the store.
      *
-     * @access public
-     *
-     * @param string $oid            Object ID to query.
-     * @param optional enum $type    NOT USED
-     * @param optional integer $val  NOT USED
+     * @param string $oid   Object ID to query.
+     * @param enum $type    NOT USED
+     * @param integer $val  NOT USED
      *
      * @return mixed  The requested object, or false on failure.
      */
-    function query($oid, $type = null, $val = null)
+    function &query($oid, $type = null, $val = null)
     {
         if (!isset($_SESSION[$this->_name]) ||
             (is_null($oid) || !isset($_SESSION[$this->_name][$oid]))) {
-            return false;
+            $object = false;
         } else {
-            return unserialize($_SESSION[$this->_name][$oid]['data']);
+            $object = unserialize($_SESSION[$this->_name][$oid]['data']);
         }
+        return $object;
     }
 
     /**
      * Sets the prune flag on a store object.
      *
-     * @access public
-     *
      * @param string $oid     The object ID.
      * @param boolean $prune  True to allow pruning, false for no pruning.
      */
@@ -218,8 +199,6 @@ class Horde_SessionObjects {
     /**
      * Generates an OID for an object.
      *
-     * @access public
-     *
      * @param mixed $data  The data to store in the store.
      *
      * @return string $oid  An object ID to use as the storage key.
