@@ -1,12 +1,14 @@
 <?php
 
+require_once 'Horde/Util.php';
+
 $GLOBALS['_HORDE_STRING_CHARSET'] = 'iso-8859-1';
 
 /**
  * The String:: class provides static methods for charset and locale safe
  * string manipulation.
  *
- * $Horde: framework/Util/String.php,v 1.43.6.1 2005/01/03 12:19:19 jan Exp $
+ * $Horde: framework/Util/String.php,v 1.43.6.8 2005/07/03 05:22:37 selsky Exp $
  *
  * Copyright 2003-2005 Jan Schneider <jan@horde.org>
  *
@@ -14,7 +16,6 @@ $GLOBALS['_HORDE_STRING_CHARSET'] = 'iso-8859-1';
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jan Schneider <jan@horde.org>
- * @version $Revision: 1.43.6.1 $
  * @since   Horde 3.0
  * @package Horde_Util
  */
@@ -43,28 +44,44 @@ class String {
      * The original string is returned if conversion failed or none
      * of the extensions were available.
      *
-     * @param mixed $input  The data to be converted. If $input is an an array,
-     *                      the array's values get converted recursively.
-     * @param string $from  The string's current charset.
-     * @param string $to    The charset to convert the string to. If not
-     *                      specified, the global variable
-     *                      $_HORDE_STRING_CHARSET will be used.
+     * @param mixed $input        The data to be converted. If $input is an an
+     *                            array, the array's values get converted
+     *                            recursively.
+     * @param string $from        The string's current charset.
+     * @param string $to          The charset to convert the string to. If not
+     *                            specified, the global variable
+     *                            $_HORDE_STRING_CHARSET will be used.
+     * @param boolean $recursion  Internally used.
      *
      * @return string  The converted string.
      */
-    function convertCharset($input, $from, $to = null)
+    function convertCharset($input, $from, $to = null, $recursion = false)
     {
+        /* Get the user's default character set if none passed in. */
+        if (is_null($to)) {
+            $to = $GLOBALS['_HORDE_STRING_CHARSET'];
+        }
+
+        /* If the from and to character sets are identical, return now. */
+        if (!$recursion) {
+            $from = String::lower($from);
+            $to = String::lower($to);
+        }
+        if ($from == $to) {
+            return $input;
+        }
+
         if (is_array($input)) {
             $tmp = array();
             foreach ($input as $key => $val) {
-                $tmp[String::convertCharset($key, $from, $to)] = String::convertCharset($val, $from, $to);
+                $tmp[String::convertCharset($key, $from, $to, true)] = String::convertCharset($val, $from, $to, true);
             }
             return $tmp;
         }
         if (is_object($input)) {
             $vars = get_object_vars($input);
             foreach ($vars as $key => $val) {
-                $input->$key = String::convertCharset($val, $from, $to);
+                $input->$key = String::convertCharset($val, $from, $to, true);
             }
             return $input;
         }
@@ -75,33 +92,20 @@ class String {
 
         $output = false;
 
-        /* Get the user's default character set if none passed in. */
-        if (is_null($to)) {
-            $to = $GLOBALS['_HORDE_STRING_CHARSET'];
-        }
-
-        /* If the from and to chaacter sets are identical, return
-         * now. */
-        $str_from = String::lower($from);
-        $str_to = String::lower($to);
-        if ($str_from == $str_to) {
-            return $input;
-        }
-
         /* Use utf8_[en|de]code() if possible. */
-        $str_from_check = (($str_from == 'iso-8859-1') || ($str_from == 'us-ascii'));
-        if ($str_from_check && ($str_to == 'utf-8')) {
+        $from_check = (($from == 'iso-8859-1') || ($from == 'us-ascii'));
+        if ($from_check && ($to == 'utf-8')) {
             return utf8_encode($input);
         }
 
-        $str_to_check = (($str_to == 'iso-8859-1') || ($str_to == 'us-ascii'));
-        if (($str_from == 'utf-8') && $str_to_check) {
+        $to_check = (($to == 'iso-8859-1') || ($to == 'us-ascii'));
+        if (($from == 'utf-8') && $to_check) {
             return utf8_decode($input);
         }
 
         /* First try iconv with transliteration. */
-        if ($str_from != 'utf7-imap' &&
-            $str_to != 'utf7-imap' &&
+        if ($from != 'utf7-imap' &&
+            $to != 'utf7-imap' &&
             Util::extensionExists('iconv')) {
             ini_set('track_errors', 1);
             /* We need to tack an extra character temporarily because
@@ -123,10 +127,10 @@ class String {
 
         /* At last try imap_utf7_[en|de]code if appropriate. */
         if (!$output && Util::extensionExists('imap')) {
-            if ($str_from_check && ($str_to == 'utf7-imap')) {
+            if ($from_check && ($to == 'utf7-imap')) {
                 return @imap_utf7_encode($input);
             }
-            if (($str_from == 'utf7-imap') && $str_to_check) {
+            if (($from == 'utf7-imap') && $to_check) {
                 return @imap_utf7_decode($input);
             }
         }
@@ -247,11 +251,12 @@ class String {
     /**
      * Returns part of a string.
      *
-     * @param string $string  The string to be converted.
-     * @param int $start      The part's start position, zero based.
-     * @param int $length     The part's length.
-     * @param string $charset The charset to use when calculating the part's
-     *                        position and length, defaults to current charset.
+     * @param string $string   The string to be converted.
+     * @param integer $start   The part's start position, zero based.
+     * @param integer $length  The part's length.
+     * @param string $charset  The charset to use when calculating the part's
+     *                         position and length, defaults to current
+     *                         charset.
      *
      * @return string  The string's part.
      */
@@ -304,12 +309,12 @@ class String {
      *
      * @param string $haystack  The string to search through.
      * @param string $needle    The string to search for.
-     * @param int $offset       Allows to specify which character in haystack
+     * @param integer $offset   Allows to specify which character in haystack
      *                          to start searching.
      * @param string $charset   The charset to use when searching for the
      *                          $needle string.
      *
-     * @return int  The position of first occurrence.
+     * @return integer  The position of first occurrence.
      */
     function pos($haystack, $needle, $offset = 0, $charset = null)
     {
@@ -333,7 +338,7 @@ class String {
      * This method behaves exactly like str_pad but is multibyte safe.
      *
      * @param string $input    The string to be padded.
-     * @param int $length      The length of the resulting string.
+     * @param integer $length  The length of the resulting string.
      * @param string $pad      The string to pad the input string with. Must
      *                         be in the same charset like the input string.
      * @param const $type      The padding type. One of STR_PAD_LEFT,
@@ -386,20 +391,14 @@ class String {
      *
      * @todo Make multibyte-save.
      *
-     * @access public
-     *
-     * @param string $text                 String containing the text to wrap.
-     * @param optional integer $length     Wrap $text at this number of
-     *                                     characters.
-     * @param optional string $break_char  Character(s) to use when breaking
-     *                                     lines.
-     * @param optional string $charset     Character set to use when breaking
-     *                                     lines.
-     * @param optional boolean $quote      Ignore lines that are wrapped with
-     *                                     the '>' character (RFC 2646)? If
-     *                                     true, we don't remove any padding
-     *                                     whitespace at the end of the
-     *                                     string.
+     * @param string $text        String containing the text to wrap.
+     * @param integer $length     Wrap $text at this number of characters.
+     * @param string $break_char  Character(s) to use when breaking lines.
+     * @param string $charset     Character set to use when breaking lines.
+     * @param boolean $quote      Ignore lines that are wrapped with the '>'
+     *                            character (RFC 2646)? If true, we don't
+     *                            remove any padding whitespace at the end of
+     *                            the string.
      *
      * @return string  String containing the wrapped text.
      */
