@@ -1,4 +1,7 @@
 <?php
+
+require_once 'Horde.php';
+
 /**
  * The Text_Filter_bbcode:: class finds bbcode-style markup (see below) in a
  * block of text and turns it into HTML.
@@ -46,7 +49,7 @@
  *         and the text is "Mail to Carlos".
  * </pre>
  *
- * $Horde: framework/Text_Filter/Filter/bbcode.php,v 1.8.10.1 2005/01/03 12:19:16 jan Exp $
+ * $Horde: framework/Text_Filter/Filter/bbcode.php,v 1.8.10.3 2005/06/23 19:57:41 selsky Exp $
  *
  * Copyright 2003-2005 Carlos Pedrinaci <cpedrinaci@yahoo.es>
  *
@@ -56,8 +59,7 @@
  * See the enclosed file COPYING for license information (LGPL). If you did
  * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @author Carlos Pedrinaci <cpedrinaci@yahoo.es>
- * @version $Revision: 1.8.10.1 $
+ * @author  Carlos Pedrinaci <cpedrinaci@yahoo.es>
  * @package Horde_Text
  */
 class Text_Filter_bbcode extends Text_Filter {
@@ -65,7 +67,7 @@ class Text_Filter_bbcode extends Text_Filter {
     /**
      * Filter parameters.
      *
-     * @var array $_params
+     * @var array
      */
     var $_params = array('entities' => false);
 
@@ -102,10 +104,11 @@ class Text_Filter_bbcode extends Text_Filter {
             '[numlist]' => '<ol>', '[/numlist]' => '</ol>',
             '[*]' => '<li>');
 
-        /* When checking URLs we validate part of them, but it is up to the
-         * user to write them correctly (in particular the query
-         * string). Concerning mails we use the regular expression in
-         * Mail_RFC822::isValidInetAddress but slightly modified. */
+        /* When checking URLs we validate part of them, but it is up
+         * to the user to write them correctly (in particular the
+         * query string). Concerning mails we use the regular
+         * expression in Mail_RFC822's isValidInetAddress() function,
+         * slightly modified. */
         $regexp = array(
             "#\[url\]((http|https)://([a-zA-Z\d][\w-]*)(\.[a-zA-Z\d][\w-]*)+(:(\d+))?(/([^<>]+))*)\[/url\]#U" =>
             Horde::link("$1", "$1") . "$1</a>",
