@@ -8,10 +8,9 @@
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/Tree/Tree/javascript.php,v 1.34.2.2 2005/01/05 10:33:01 jan Exp $
+ * $Horde: framework/Tree/Tree/javascript.php,v 1.34.2.7 2005/07/03 05:22:36 selsky Exp $
  *
  * @author  Marko Djukic <marko@oblo.com>
- * @version $Revision: 1.34.2.2 $
  * @package Horde_Tree
  * @since   Horde 3.0
  */
@@ -20,28 +19,26 @@ class Horde_Tree_javascript extends Horde_Tree {
     /**
      * The name of the source for the tree data.
      *
-     * @var string $_source_name
+     * @var string
      */
     var $_source_name = null;
 
     /**
      * The name of the target element to output the javascript tree.
      *
-     * @var string $_options_name
+     * @var string
      */
     var $_options_name = null;
 
     /**
      * The name of the target element to output the javascript tree.
      *
-     * @var string $_target_name
+     * @var string
      */
     var $_target_name = null;
 
     /**
      * Constructor
-     *
-     * @access public
      */
     function Horde_Tree_javascript($tree_name, $params = array())
     {
@@ -72,8 +69,6 @@ class Horde_Tree_javascript extends Horde_Tree {
     /**
      * Returns the tree.
      *
-     * @access public
-     *
      * @param boolean $static  If true the tree nodes can't be expanded and
      *                         collapsed and the tree gets rendered expanded.
      *
@@ -86,12 +81,13 @@ class Horde_Tree_javascript extends Horde_Tree {
         $this->_header_name = 'h_' . $this->_instance;
         $this->_options_name = 'o_' . $this->_instance;
         $this->_target_name = 't_' . $this->_instance;
+        $this->_buildIndents($this->_root_nodes);
 
-        Horde::addScriptFile('tree.js', 'horde');
         $tree = $this->_getTreeSource() .
              '<div id="' . $this->_target_name . '"></div>' .
              $this->_getTreeInit();
 
+        Horde::addScriptFile('tree.js', 'horde');
         return $tree;
     }
 
@@ -111,20 +107,18 @@ class Horde_Tree_javascript extends Horde_Tree {
     /**
      * Returns just the JS node definitions as a string.
      *
-     * @access public
-     *
      * @return string  The Javascript node array definitions.
      */
     function renderNodeDefinitions()
     {
+        $this->_buildIndents($this->_root_nodes);
+
         $nodeJs = '';
         foreach ($this->_nodes as $node_id => $node) {
             $nodeJs .= $this->_getJsArrayElement(sprintf('%s[\'%s\']', 'n_' . $this->_instance, $node_id), $node);
         }
 
-        $nodeJs .= $this->_instance . '.renderTree(root_nodes);';
-
-        return $nodeJs;
+        return $nodeJs . $this->_instance . '.renderTree(root_nodes);';
     }
 
     /**
