@@ -2,7 +2,7 @@
 /**
  * The Horde_UI_VarRenderer_html:: class renders variables to HTML.
  *
- * $Horde: framework/UI/UI/VarRenderer/html.php,v 1.98.2.1 2005/01/03 12:19:19 jan Exp $
+ * $Horde: framework/UI/UI/VarRenderer/html.php,v 1.98.2.12 2005/09/23 13:30:28 jan Exp $
  *
  * Copyright 2003-2005 Jason M. Felice <jfelice@cronosys.com>
  *
@@ -240,7 +240,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
 
             /* Keep also original if it has been requested. */
             if ($var->type->_show_keeporig) {
-                $html .= sprintf('<input type="checkbox" name="%s"%s />%s' . "\n",
+                $html .= sprintf('<input type="checkbox" class="checkbox" name="%s"%s />%s' . "\n",
                        $varname . '[keep_orig]',
                        !empty($image['keep_orig']) ? ' checked="checked"' : '',
                        _("Keep original?"));
@@ -265,7 +265,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
                         $var->type->getCols(),
                         $var->type->getRows(),
                         $this->_getActionScripts($form, $var),
-                        $var->getValue($vars));
+                        htmlspecialchars($var->getValue($vars)));
 
         if ($var->type->hasHelper('rte') && $browser->hasFeature('rte')) {
             require_once 'Horde/Editor.php';
@@ -273,7 +273,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         }
 
         if ($var->type->hasHelper() && $browser->hasFeature('javascript')) {
-            $html .= '<br /><table border="0" cellpadding="1" cellspacing="0"><tr><td>';
+            $html .= '<br /><table cellspacing="0"><tr><td>';
             Horde::addScriptFile('open_html_helper.js', 'horde');
             $imgId = $this->_genID($var->getVarName(), false) . 'ehelper';
             if ($var->type->hasHelper('emoticons')) {
@@ -297,7 +297,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
 
     function _renderVarInput_address(&$form, &$var, &$vars)
     {
-        return sprintf('<textarea id="%s" name="%s" cols="%s" rows="%s"%s>%s</textarea>',
+        return sprintf('<textarea %s name="%s" cols="%s" rows="%s"%s>%s</textarea>',
                        $this->_genID($var->getVarName()),
                        $var->getVarName(),
                        $var->type->getCols(),
@@ -328,7 +328,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         $time = $var->type->getTimeParts($var->getValue($vars));
 
         /* Output hours. */
-        $hours = array('' => _("HH"));
+        $hours = array('' => _("hh"));
         for ($i = 0; $i <= 23; $i++) {
             $hours[sprintf('%02d', $i)] = $i;
         }
@@ -339,7 +339,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
                         $this->_getActionScripts($form, $var));
 
         /* Output minutes. */
-        $minutes = array('' => _("MM"));
+        $minutes = array('' => _("mm"));
         for ($i = 0; $i <= 59; $i++) {
             $minutes[sprintf('%02d', $i)] = $i;
         }
@@ -355,7 +355,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         }
 
         /* Output seconds. */
-        $seconds = array('' => _("SS"));
+        $seconds = array('' => _("ss"));
         for ($i = 0; $i <= 59; $i++) {
             $seconds[sprintf('%02d', $i)] = $i;
         }
@@ -462,7 +462,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
     {
         global $registry, $browser;
 
-        $html = '<table border="0" cellpadding="0" cellspacing="0"><tr><td>' .
+        $html = '<table cellspacing="0"><tr><td>' .
                 '<input type="text" size="10" maxlength="7" name="' .
                 $var->getVarName() . '" id="' . $var->getVarName() .
                 '" value="' . $var->getValue($vars) . '" /></td>';
@@ -485,22 +485,19 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
 
         Horde::addScriptFile('sorter.js', 'horde', true);
 
-        $html = '<input type="hidden" name="' . $varname .
-                '[array]" value="" ' . $this->_genID($varname . '[array]') .
-                ' /><table border="0" cellpadding="0" cellspacing="0"><tr>' .
-                '<td><select multiple="multiple" size="' .
-                $var->type->getSize() . '" name="' . $varname .
-                '[list]" onchange="' . $instance . '.deselectHeader();" ' .
-                $this->_genID($varname . '[list]') . '>';
-        $html .= $var->type->getOptions($var->getValue($vars)) . '</select></td><td>';
-        $html .= Horde::link('#', _("Move up"), '', '', $instance . '.moveColumnUp(); return false;') . Horde::img('nav/up.png', _("Move up"), '', $registry->getImageDir('horde')) . '</a><br />';
-        $html .= Horde::link('#', _("Move up"), '', '', $instance . '.moveColumnDown(); return false;') . Horde::img('nav/down.png', _("Move down"), '', $registry->getImageDir('horde')) . '</a></td></tr></table>';
-        $html .= '<script language="JavaScript" type="text/javascript">' . "\n";
-        $html .= sprintf('%1$s = new Horde_Form_Sorter(\'%1$s\', \'%2$s\', \'%3$s\');' . "\n",
-               $instance, $varname, $var->type->getHeader());
-
-        $html .= sprintf("%s.setHidden();\n</script>\n", $instance);
-        return $html;
+        return '<input type="hidden" name="' . $varname .
+            '[array]" value="" ' . $this->_genID($varname . '[array]') . '/>' .
+            '<select class="leftFloat" multiple="multiple" size="' .
+            $var->type->getSize() . '" name="' . $varname .
+            '[list]" onchange="' . $instance . '.deselectHeader();" ' .
+            $this->_genID($varname . '[list]') . '>' .
+            $var->type->getOptions($var->getValue($vars)) . '</select><div class="leftFloat">' .
+            Horde::link('#', _("Move up"), '', '', $instance . '.moveColumnUp(); return false;') . Horde::img('nav/up.png', _("Move up"), '', $registry->getImageDir('horde')) . '</a><br />' .
+            Horde::link('#', _("Move up"), '', '', $instance . '.moveColumnDown(); return false;') . Horde::img('nav/down.png', _("Move down"), '', $registry->getImageDir('horde')) . '</a></div>' .
+            '<script language="JavaScript" type="text/javascript">' . "\n" .
+            sprintf('%1$s = new Horde_Form_Sorter(\'%1$s\', \'%2$s\', \'%3$s\');' . "\n",
+                    $instance, $varname, $var->type->getHeader()) .
+            sprintf("%s.setHidden();\n</script>\n", $instance);
     }
 
     function _renderVarInput_assign(&$form, &$var, &$vars)
@@ -551,7 +548,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         $prompt = $var->type->getPrompt();
         $htmlchars = $var->getOption('htmlchars');
         if (!empty($prompt)) {
-            $prompt = '<option value="">' . ($htmlchars ? @htmlspecialchars($prompt, ENT_QUOTES, NLS::getCharset()) : $prompt) . '</option>';
+            $prompt = '<option value="">' . ($htmlchars ? $prompt : @htmlspecialchars($prompt, ENT_QUOTES, NLS::getCharset())) . '</option>';
         }
         return sprintf('<select name="%s" %s%s>%s%s</select>',
                $var->getVarName(),
@@ -579,17 +576,18 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
 
         /* Hidden tag to store the current first level. */
         $html = sprintf('<input type="hidden" name="%s[old]" value="%s" %s />',
-               $varname,
-               @htmlspecialchars($selected['1'], ENT_QUOTES, NLS::getCharset()),
-               $this->_genID($varname . '[old]'));
+                        $varname,
+                        @htmlspecialchars($selected['1'], ENT_QUOTES, NLS::getCharset()),
+                        $this->_genID($varname . '[old]'));
 
         /* First level. */
         require_once 'Horde/Array.php';
         $values_1 = Horde_Array::valuesToKeys(array_keys($values));
-        $html .= sprintf('<select %s name="%s[1]"%s>',
-               $this->_genID($varname . '[1]'),
-               $varname,
-               ($var->hasAction() ? ' ' . $this->_genActionScript($form, $var->_action, $varname) : ''));
+        $html .= sprintf('<select %s name="%s[1]" onchange="%s"%s>',
+                         $this->_genID($varname . '[1]'),
+                         $varname,
+                         'if (this.value) { document.' . $form->getName() . '.formname.value=\'\';' . 'document.' . $form->getName() . '.submit() }',
+                         ($var->hasAction() ? ' ' . $this->_genActionScript($form, $var->_action, $varname) : ''));
         if (!empty($prompts)) {
             $html .= '<option value="">' . @htmlspecialchars($prompts[0], ENT_QUOTES, NLS::getCharset()) . '</option>';
         }
@@ -608,8 +606,8 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         if (!empty($selected['1'])) {
             $values_2 = &$values[$selected['1']];
         }
-        $html .= $this->_selectOptions($values_2, $selected['2']);
-        $html .= '</select>';
+        $html .= $this->_selectOptions($values_2, $selected['2']) . '</select>';
+
         return $html;
     }
 
@@ -672,7 +670,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         $matrix    = $var->type->getMatrix();
         $new_input = $var->type->getNewInput();
 
-        $html = '<table border="0" cellpadding="0" cellspacing="0"><tr>';
+        $html = '<table cellspacing="0"><tr>';
 
         $html .= '<td align="right" width="20%"></td>';
         foreach ($cols as $col_title) {
@@ -697,7 +695,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
             }
             $html .= ' </td>';
             foreach ($cols as $col_id => $col_title) {
-                $html .= sprintf('<td align="center"><input type="checkbox" name="%s[n][v][%s]" /></td>', $varname, $col_id);
+                $html .= sprintf('<td align="center"><input type="checkbox" class="checkbox" name="%s[n][v][%s]" /></td>', $varname, $col_id);
             }
             $html .= '<td> </td></tr>';
         }
@@ -706,7 +704,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         foreach ($rows as $row_id => $row_title) {
             $html .= sprintf('<tr><td>%s</td>', $row_title);
             foreach ($cols as $col_id => $col_title) {
-                $html .= sprintf('<td align="center"><input type="checkbox" name="%s[r][%s][%s]"%s /></td>', $varname, $row_id, $col_id, (!empty($matrix[$row_id][$col_id]) ? ' checked="checked"' : ''));
+                $html .= sprintf('<td align="center"><input type="checkbox" class="checkbox" name="%s[r][%s][%s]"%s /></td>', $varname, $row_id, $col_id, (!empty($matrix[$row_id][$col_id]) ? ' checked="checked"' : ''));
             }
             $html .= '<td> </td></tr>';
         }
@@ -755,7 +753,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
     {
         $varName = $var->getVarName();
 
-        $html = '<input type="checkbox" name="' .  $varName . '"' .
+        $html = '<input type="checkbox" class="checkbox" name="' .  $varName . '"' .
             ($var->getValue($vars) ? ' checked="checked"' : '');
         if ($var->hasAction()) {
             $html .= $this->_genActionScript($form, $var->_action,
@@ -810,7 +808,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
             Horde::addScriptFile('popup.js', 'horde', true);
             $imgId = $this->_genID($varname, false) . 'goto';
             $html .= '<div id="goto" class="headerbox" style="position:absolute;visibility:hidden;padding:0px;"></div>';
-            $html .= Horde::link('#', _("Select an object"), '', '', 'obrowserWindowName = popup(\'' . $GLOBALS['registry']->get('webroot', 'horde') . '/services/obrowser/' . '\'); return false;') . Horde::img('tree/leaf.png', _("Object"), 'id="' . $imgId . '" align="middle"', $GLOBALS['registry']->getImageDir('horde')) . "</a>\n";
+            $html .= Horde::link('#', _("Select an object"), '', '', 'obrowserWindow = popup(\'' . $GLOBALS['registry']->get('webroot', 'horde') . '/services/obrowser/' . '\'); obrowserWindowName = obrowserWindow.name; return false;') . Horde::img('tree/leaf.png', _("Object"), 'id="' . $imgId . '" align="middle"', $GLOBALS['registry']->getImageDir('horde')) . "</a>\n";
         }
 
         return $html;
@@ -968,6 +966,8 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
 
     function _renderVarDisplay_address(&$form, &$var, &$vars)
     {
+        global $registry;
+
         $address = $var->getValue($vars);
 
         if (preg_match('/(.*)\n(.*)\s*,\s*(\w+)\.?\s+(\d+|[a-zA-Z]\d[a-zA-Z]\s?\d[a-zA-Z]\d)/', $address, $addressParts)) {
@@ -1003,7 +1003,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
             if (!empty($addressParts[1])) {
                 $mapurl2 .= '&addr=' . urlencode($addressParts[1]);
             }
-            /* give precedence on zipcode over city/state */
+            /* Give precedence to zipcode over city/state */
             if (empty($addressParts[4]) && !empty($addressParts[2]) && !empty($addressParts[3])) {
                 $mapurl2 .= '&csz=' . urlencode($addressParts[2] . ' ' . $addressParts[3]);
             }
@@ -1049,7 +1049,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
                 }
             }
 
-            /* Mapquest generated map */
+            /* Mapquest generated map. */
             $mapurl2 = 'http://www.mapquest.com/maps/map.adp?country=' . String::upper($country);
             $desc2 = _("MapQuest map");
             $icon2 = 'map_eu.png';
@@ -1063,14 +1063,15 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
                 $mapurl2 .= '&city=' . urlencode($addressParts[4]);
             }
         }
+
         $html = nl2br(@htmlspecialchars($var->getValue($vars), ENT_QUOTES, NLS::getCharset()));
         if (!empty($mapurl)) {
-            global $registry;
-            $html .= '&nbsp;&nbsp;' . Horde::link($mapurl, $desc, null, '_blank') . Horde::img($icon, $desc, 'align="middle"', $registry->getImageDir('horde')) . '</a>';
+            $html .= '&nbsp;&nbsp;' . Horde::link(Horde::externalUrl($mapurl), $desc, null, '_blank') . Horde::img($icon, $desc, 'align="middle"', $registry->getImageDir('horde')) . '</a>';
         }
         if (!empty($mapurl2)) {
-            $html .= '&nbsp;' . Horde::link($mapurl2, $desc2, null, '_blank') . Horde::img($icon2, $desc2, 'align="middle"', $registry->getImageDir('horde')) . '</a>';
+            $html .= '&nbsp;' . Horde::link(Horde::externalUrl($mapurl2), $desc2, null, '_blank') . Horde::img($icon2, $desc2, 'align="middle"', $registry->getImageDir('horde')) . '</a>';
         }
+
         return $html;
     }
 
@@ -1105,7 +1106,6 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
             $values = array($values);
         }
 
-
         $count = count($values);
         $html = '';
         for ($i = 0; $i < $count; $i++) {
@@ -1174,21 +1174,28 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         return $html;
     }
 
-    function _selectOptions(&$values, $selectedValue = false, $htmlchars = true)
+    function _selectOptions(&$values, $selectedValue = false,
+                            $htmlchars = false)
     {
         $result = '';
         $sel = false;
         foreach ($values as $value => $display) {
-            if (!is_null($selectedValue) && !$sel && $value == $selectedValue && strlen($value) == strlen($selectedValue)) {
+            if (!is_null($selectedValue) && !$sel &&
+                $value == $selectedValue &&
+                strlen($value) == strlen($selectedValue)) {
                 $selected = ' selected="selected"';
                 $sel = true;
             } else {
                 $selected = '';
             }
             $result .= ' <option value="';
-            $result .= ($htmlchars) ? @htmlspecialchars($value, ENT_QUOTES, NLS::getCharset()) : $value;
+            $result .= $htmlchars
+                ? $value
+                : @htmlspecialchars($value, ENT_QUOTES, NLS::getCharset());
             $result .= '"' . $selected . '>';
-            $result .= ($htmlchars) ? htmlspecialchars($display) : $display;
+            $result .= $htmlchars
+                ? $display
+                : @htmlspecialchars($display, ENT_QUOTES, NLS::getCharset());
             $result .= "</option>\n";
         }
 
@@ -1220,7 +1227,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         $i = 0;
         foreach ($values as $value => $display) {
             $checked = (in_array($value, $checkedValues)) ? ' checked="checked"' : '';
-            $result .= sprintf('<input id="%s%s" type="checkbox" name="%s[]" value="%s"%s%s /><label for="%s%s">&nbsp;%s</label><br />',
+            $result .= sprintf('<input id="%s%s" type="checkbox" class="checkbox" name="%s[]" value="%s"%s%s /><label for="%s%s">&nbsp;%s</label><br />',
                                $name,
                                $i,
                                $name,
@@ -1242,7 +1249,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         $i = 0;
         foreach ($values as $value => $display) {
             $checked = (!is_null($checkedValue) && $value == $checkedValue) ? ' checked="checked"' : '';
-            $result .= sprintf('<input id="%s%s" type="radio" name="%s" value="%s"%s%s /><label for="%s%s">&nbsp;%s</label><br />',
+            $result .= sprintf('<input id="%s%s" type="radio" class="checkbox" name="%s" value="%s"%s%s /><label for="%s%s">&nbsp;%s</label><br />',
                                $name,
                                $i,
                                $name,
@@ -1260,7 +1267,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
 
     function _genID($name, $fulltag = true)
     {
-        return $fulltag ? 'id="' . @htmlspecialchars($name, ENT_QUOTES, NLS::getCharset()) . '"' : $name;
+        return $fulltag ? 'id="' . htmlspecialchars($name) . '"' : $name;
     }
 
     function _genActionScript(&$form, $action, $varname)
