@@ -7,7 +7,7 @@ require_once dirname(__FILE__) . '/rcs.php';
  *
  * Copyright 2000-2005 Anil Madhavapeddy, <anil@recoil.org>
  *
- * $Horde: framework/VC/VC/cvs.php,v 1.32.2.5 2005/02/02 18:46:04 chuck Exp $
+ * $Horde: framework/VC/VC/cvs.php,v 1.32.2.15 2005/09/28 11:45:01 jan Exp $
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
  * @package VC
@@ -41,7 +41,8 @@ class VC_cvs extends VC_rcs {
 
     function &queryDir($where)
     {
-        return $dir = &new VC_Directory_cvs($this, $where);
+        $dir = &new VC_Directory_cvs($this, $where);
+        return $dir;
     }
 
     function getCheckout($file, $rev)
@@ -49,7 +50,7 @@ class VC_cvs extends VC_rcs {
         return VC_Checkout_cvs::get($this, $file->queryFullPath(), $rev);
     }
 
-    function &getDiff(&$file, $rev1, $rev2, $type = 'context', $num = 3, $ws = true)
+    function getDiff(&$file, $rev1, $rev2, $type = 'context', $num = 3, $ws = true)
     {
         return VC_Diff_cvs::get($this, $file, $rev1, $rev2, $type, $num, $ws);
     }
@@ -59,17 +60,20 @@ class VC_cvs extends VC_rcs {
         if (substr($filename, 0, 1) != '/') {
             $filename = '/' . $filename;
         }
-        return VC_File_cvs::getFileObject($this, $this->sourceroot() . $filename, $cache, $quicklog);
+        $fo = &VC_File_cvs::getFileObject($this, $this->sourceroot() . $filename, $cache, $quicklog);
+        return $fo;
     }
 
     function &getAnnotateObject($filename)
     {
-        return $blame = &new VC_Annotate_cvs($this, $filename, Util::getTempFile('vc', true, $this->_paths['temp']));
+        $blame = &new VC_Annotate_cvs($this, $filename, Util::getTempFile('vc', true, $this->_paths['temp']));
+        return $blame;
     }
 
     function &getPatchsetObject($filename, $cache = null)
     {
-        return VC_Patchset_cvs::getPatchsetObject($this, $this->sourceroot() . '/' . $filename, $cache);
+        $po = &VC_Patchset_cvs::getPatchsetObject($this, $this->sourceroot() . '/' . $filename, $cache);
+        return $po;
     }
 
 }
@@ -194,10 +198,10 @@ class VC_Checkout_cvs {
      * Static function which returns a file pointing to the head of the
      * requested revision of an RCS file.
      *
-     * @param object VC_cvs $rep  A repository object
-     * @param string $fullname    Fully qualified pathname of the desired RCS
-     *                            file to checkout
-     * @param string $rev         RCS revision number to check out
+     * @param VC_cvs $rep       A repository object
+     * @param string $fullname  Fully qualified pathname of the desired RCS
+     *                          file to checkout
+     * @param string $rev       RCS revision number to check out
      *
      * @return resource|object  Either a PEAR_Error object, or a stream
      *                          pointer to the head of the checkout
@@ -256,20 +260,20 @@ class VC_Diff_cvs {
     /**
      * Obtain the differences between two revisions of a file.
      *
-     * @param object VC_cvs $rep        A repository object.
-     * @param object VC_File_cvs $file  The desired file.
-     * @param string  $rev1             Original revision number to compare
-     *                                  from.
-     * @param string  $rev2             New revision number to compare against.
-     * @param string  $type             The type of diff (e.g. 'unified').
-     * @param integer $num              Number of lines to be used in context
-     *                                  and unified diffs.
-     * @param boolean $ws               Show whitespace in the diff?
+     * @param VC_cvs $rep        A repository object.
+     * @param VC_File_cvs $file  The desired file.
+     * @param string $rev1       Original revision number to compare from.
+     * @param string $rev2       New revision number to compare against.
+     * @param string $type       The type of diff (e.g. 'unified').
+     * @param integer $num       Number of lines to be used in context and
+     *                           unified diffs.
+     * @param boolean $ws        Show whitespace in the diff?
      *
-     * @return string|boolean  False on failure, or a string containing the diff
-     *                         on success.
+     * @return string|boolean  False on failure, or a string containing the
+     *                         diff on success.
      */
-    function get(&$rep, &$file, $rev1, $rev2, $type = 'context', $num = 3, $ws = true)
+    function get(&$rep, &$file, $rev1, $rev2, $type = 'context', $num = 3,
+                 $ws = true)
     {
         /* Make sure that the file parameter is valid. */
         if (is_a($file, 'PEAR_Error')) {
@@ -349,9 +353,9 @@ class VC_Directory_cvs {
      * Creates a CVS Directory object to store information
      * about the files in a single directory in the repository.
      *
-     * @param object VC_cvs $rep           A repository object
-     * @param string                  $dn  Path to the directory.
-     * @param object VC_Directory_cvs $pn  The parent VC_Directory to this one.
+     * @param VC_cvs $rep           A repository object
+     * @param string $dn            Path to the directory.
+     * @param VC_Directory_cvs $pn  The parent VC_Directory to this one.
      */
     function VC_Directory_cvs($rep, $dn, $pn = '')
     {
@@ -394,7 +398,7 @@ class VC_Directory_cvs {
      * retrieve a list of all the objects in there.  It then populates
      * the file/directory stack and makes it available for retrieval.
      *
-     * @return bool|object  PEAR_Error object on an error, true on success.
+     * @return boolean|object  PEAR_Error object on an error, true on success.
      */
     function browseDir($cache = null, $quicklog = true, $showattic = false)
     {
@@ -453,11 +457,11 @@ class VC_Directory_cvs {
      * Sort the contents of the directory in a given fashion and
      * order.
      *
-     * @param int $how  Of the form VC_SORT_* where * can be:
-     *                  NONE, NAME, AGE, REV for sorting by name, age or
-     *                  revision.
-     * @param int $dir  Of the form VC_SORT_* where * can be:
-     *                  ASCENDING, DESCENDING for the order of the sort.
+     * @param integer $how  Of the form VC_SORT_* where * can be:
+     *                      NONE, NAME, AGE, REV for sorting by name, age or
+     *                      revision.
+     * @param integer $dir  Of the form VC_SORT_* where * can be:
+     *                      ASCENDING, DESCENDING for the order of the sort.
      */
     function applySort($how = VC_SORT_NONE, $dir = VC_SORT_ASCENDING)
     {
@@ -589,11 +593,9 @@ class VC_File_cvs extends VC_File {
          * The version of the cached data. Increment this whenever the
          * internal storage format changes, such that we must
          * invalidate prior cached data.
-         *
-         * @var integer $cacheVersion
          */
         $cacheVersion = 2;
-        $cacheId = $filename . '_f' . (int)$quicklog . '_v' . $cacheVersion;
+        $cacheId = $rep->sourceroot() . '_n' . $filename . '_f' . (int)$quicklog . '_v' . $cacheVersion;
 
         if ($cache &&
             $cache->exists($cacheId, time() - @filemtime($filename . ',v'))) {
@@ -619,7 +621,7 @@ class VC_File_cvs extends VC_File {
      * If this file is present in an Attic directory, this indicates
      * it.
      *
-     * @return bool  True if file is in the Attic, and false otherwise
+     * @return boolean  True if file is in the Attic, and false otherwise
      */
     function isAtticFile()
     {
@@ -692,9 +694,9 @@ class VC_File_cvs extends VC_File {
     /**
      * Sort the list of VC_log objects that this file contains.
      *
-     * @param int $how  VC_SORT_REV (sort by revision),
-     *                  VC_SORT_NAME (sort by author name),
-     *                  VC_SORT_AGE (sort by commit date)
+     * @param integer $how  VC_SORT_REV (sort by revision),
+     *                      VC_SORT_NAME (sort by author name),
+     *                      VC_SORT_AGE (sort by commit date)
      */
     function applySort($how = VC_SORT_REV)
     {
@@ -735,15 +737,15 @@ class VC_File_cvs extends VC_File {
     }
 
     /**
-     * Populate the object with information about the revisions logs
-     * and dates of the file.
+     * Populate the object with information about the revisions logs and dates
+     * of the file.
      *
-     * @return bool|object  PEAR_Error object on error, or true on success
+     * @return boolean|object  PEAR_Error object on error, or true on success
      */
     function getBrowseInfo()
     {
         /* Check that we are actually in the filesystem. */
-		$file = $this->queryFullPath();
+        $file = $this->queryFullPath();
         if (!is_file($file)) {
             return PEAR::raiseError('File Not Found: ' . $file);
         }
@@ -769,7 +771,7 @@ class VC_File_cvs extends VC_File {
             case 'init':
                 if (!strncmp('head: ', $line, 6)) {
                     $this->head = substr($line, 6);
-                } else if (!strncmp('branch:', $line, 7)) {
+                } elseif (!strncmp('branch:', $line, 7)) {
                     $state = 'rev';
                 }
                 break;
@@ -779,7 +781,7 @@ class VC_File_cvs extends VC_File {
                     $state = 'info';
                     $this->symrev = $symrev;
                     $this->revsym = $revsym;
-                } else if (preg_match("/^\s+([^:]+):\s+([\d\.]+)/", $line ,$regs)) {
+                } elseif (preg_match("/^\s+([^:]+):\s+([\d\.]+)/", $line, $regs)) {
                     // Check to see if this is a branch
                     if (preg_match('/^(\d+(\.\d+)+)\.0\.(\d+)$/',$regs[2])) {
                         $branchRev = VC_Revision::toBranch($regs[2]);
@@ -789,7 +791,7 @@ class VC_File_cvs extends VC_File {
                     } else {
                         $symrev[$regs[1]] = $regs[2];
                         if (empty($revsym[$regs[2]])) $revsym[$regs[2]]=array();
-                        array_push($revsym[$regs[2]], $regs[1]);
+                        $revsym[$regs[2]][] = $regs[1];
                     }
                 }
                 break;
@@ -798,13 +800,13 @@ class VC_File_cvs extends VC_File {
                 if (strncmp('==============================', $line, 30) &&
                     strcmp('----------------------------', $line)) {
                     $accum[] = $line;
-                } else if (count($accum)) {
+                } elseif (count($accum)) {
                     // spawn a new VC_log object and add it to the logs hash
                     $log = &new VC_Log_cvs($this);
                     $err = $log->processLog($accum);
                     // TODO: error checks - avsm
                     $this->logs[$log->queryRevision()] = &$log;
-                    array_push($this->revs, $log->queryRevision());
+                    $this->revs[] = $log->queryRevision();
                     $accum = array();
                 }
                 break;
@@ -996,11 +998,9 @@ class VC_Patchset_cvs {
          * The version of the cached data. Increment this whenever the
          * internal storage format changes, such that we must
          * invalidate prior cached data.
-         *
-         * @var integer $cacheVersion
          */
         $cacheVersion = 1;
-        $cacheId = $filename . '_f' . '_v' . $cacheVersion;
+        $cacheId = $rep->sourceroot() . '_n' . $filename . '_f_v' . $cacheVersion;
 
         if ($cache &&
             $cache->exists($cacheId, time() - @filemtime($filename . ',v'))) {
@@ -1028,7 +1028,7 @@ class VC_Patchset_cvs {
      *
      * @param string $repository  The full repository location.
      *
-     * @return bool|object  PEAR_Error object on error, or true on success.
+     * @return boolean|object  PEAR_Error object on error, or true on success.
      */
     function getPatchsets($repository)
     {
