@@ -4,10 +4,9 @@
  *
  * Copyright 2000-2005 Anil Madhavapeddy, <anil@recoil.org>
  *
- * $Horde: framework/VC/VC/svn.php,v 1.28.4.1 2005/01/03 12:19:20 jan Exp $
+ * $Horde: framework/VC/VC/svn.php,v 1.28.4.12 2005/09/28 11:45:01 jan Exp $
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.28.4.1 $
  * @since   Horde 3.0
  * @package VC
  */
@@ -36,7 +35,8 @@ class VC_svn extends VC {
 
     function &queryDir($where)
     {
-        return $dir = &new VC_Directory_svn($this, $where);
+        $dir = &new VC_Directory_svn($this, $where);
+        return $dir;
     }
 
     function getCheckout($file, $rev)
@@ -44,24 +44,27 @@ class VC_svn extends VC {
         return VC_Checkout_svn::get($this, $file->queryFullPath(), $rev);
     }
 
-    function &getDiff(&$file, $rev1, $rev2, $type = 'context', $num = 3, $ws = true)
+    function getDiff(&$file, $rev1, $rev2, $type = 'context', $num = 3, $ws = true)
     {
         return VC_Diff_svn::get($this, $file, $rev1, $rev2, $type, $num, $ws);
     }
 
     function &getFileObject($filename, $cache = null, $quicklog = false)
     {
-        return VC_File_svn::getFileObject($this, $filename, $cache, $quicklog);
+        $fo = &VC_File_svn::getFileObject($this, $filename, $cache, $quicklog);
+        return $fo;
     }
 
     function &getAnnotateObject($filename)
     {
-        return $blame = &new VC_Annotate_svn($this, $filename);
+        $blame = &new VC_Annotate_svn($this, $filename);
+        return $blame;
     }
 
     function &getPatchsetObject($filename, $cache = null)
     {
-        return VC_Patchset_svn::getPatchsetObject($this, $filename, $cache);
+        $po = &VC_Patchset_svn::getPatchsetObject($this, $filename, $cache);
+        return $po;
     }
 
 }
@@ -97,8 +100,12 @@ class VC_Annotate_svn {
             return false;
         }
 
-        $command = $this->SVN->getPath('svn') . ' annotate -r 1:' . $rev . ' ' . $this->file->queryFullPath() . ' 2>&1';
+        $Q = VC_WINDOWS ? '"' : "'";
+        $command = $this->SVN->getPath('svn') . ' annotate -r 1:' . $rev . ' ' . $Q . str_replace($Q, '\\' . $Q, $this->file->queryFullPath()) . $Q . ' 2>&1';
         $pipe = popen($command, 'r');
+        if (!$pipe) {
+            return PEAR::raiseError('Failed to execute svn annotate: ' . $command);
+        }
 
         $lines = array();
         $lineno = 1;
@@ -144,7 +151,15 @@ class VC_Checkout_svn {
             return PEAR::raiseError('Invalid revision number');
         }
 
-        if (!($RCS = popen($rep->getPath('svn') . ' cat -r ' . $rev . ' ' . $fullname . ' 2>&1', 'r'))) {
+        if (VC_WINDOWS) {
+            $Q = '"';
+            $mode = 'rb';
+        } else {
+            $Q = "'";
+            $mode = 'r';
+        }
+
+        if (!($RCS = popen($rep->getPath('svn') . ' cat -r ' . $rev . ' ' . $Q . str_replace($Q, '\\' . $Q, $fullname) . $Q . ' 2>&1', $mode))) {
             return PEAR::raiseError('Couldn\'t perform checkout of the requested file');
         }
 
@@ -166,20 +181,20 @@ class VC_Diff_svn {
     /**
      * Obtain the differences between two revisions of a file.
      *
-     * @param object VC_svn $rep        A repository object.
-     * @param object VC_File_svn $file  The desired file.
-     * @param string  $rev1             Original revision number to compare
-     *                                  from.
-     * @param string  $rev2             New revision number to compare against.
-     * @param string  $type             The type of diff (e.g. 'unified').
-     * @param integer $num              Number of lines to be used in context
-     *                                  and unified diffs.
-     * @param boolean $ws               Show whitespace in the diff?
+     * @param VC_svn $rep        A repository object.
+     * @param VC_File_svn $file  The desired file.
+     * @param string $rev1       Original revision number to compare from.
+     * @param string $rev2       New revision number to compare against.
+     * @param string $type       The type of diff (e.g. 'unified').
+     * @param integer $num       Number of lines to be used in context and
+     *                           unified diffs.
+     * @param boolean $ws        Show whitespace in the diff?
      *
-     * @return string|boolean  False on failure, or a string containing the diff
-     *                         on success.
+     * @return string|boolean  False on failure, or a string containing the
+     *                         diff on success.
      */
-    function get(&$rep, &$file, $rev1, $rev2, $type = 'context', $num = 3, $ws = true)
+    function get(&$rep, &$file, $rev1, $rev2, $type = 'context', $num = 3,
+                 $ws = true)
     {
         /* Make sure that the file parameter is valid */
         if (is_a($file, 'PEAR_Error')) {
@@ -249,9 +264,10 @@ class VC_Directory_svn {
      * Create a SVN Directory object to store information about the
      * files in a single directory in the repository
      *
-     * @param object VC_Repository_svn $rp  The VC_Repository object this directory is part of.
-     * @param string                   $dn  Path to the directory.
-     * @param object VC_Directory_svn  $pn  (optional) The parent VC_Directory to this one.
+     * @param VC_Repository_svn $rp  The VC_Repository object this directory
+     *                               is part of.
+     * @param string $dn             Path to the directory.
+     * @param VC_Directory_svn $pn   The parent VC_Directory to this one.
      */
     function VC_Directory_svn(&$rep, $dn, $pn = '')
     {
@@ -297,28 +313,39 @@ class VC_Directory_svn {
      */
     function browseDir($cache = null, $quicklog = true, $showattic = false)
     {
-        $cmd = $this->rep->getPath('svn') . ' ls ' . $this->rep->sourceroot() . $this->queryDir() . ' 2>&1';
+        $Q = VC_WINDOWS ? '"' : "'" ;
+        $cmd = $this->rep->getPath('svn') . ' ls ' . $Q . str_replace($Q, '\\' . $Q, $this->rep->sourceroot() . $this->queryDir()) . $Q . ' 2>&1';
         $dir = popen($cmd, 'r');
+        if (!$dir) {
+            return PEAR::raiseError('Failed to execute svn ls: ' . $cmd);
+        }
 
         /* Create two arrays - one of all the files, and the other of
          * all the dirs. */
         $errors = array();
         while (!feof($dir)) {
             $line = chop(fgets($dir, 1024));
-            if (strlen($line)) {
-                if (substr($line, 0, 4) == 'svn:') {
-                    $errors[] = $line;
-                } elseif (substr($line, -1) == '/') {
-                    $this->dirs[] = substr($line, 0, -1);
+            if (!strlen($line)) {
+                continue;
+            }
+
+            if (substr($line, 0, 4) == 'svn:') {
+                $errors[] = $line;
+            } elseif (substr($line, -1) == '/') {
+                $this->dirs[] = substr($line, 0, -1);
+            } else {
+                $fl = &$this->rep->getFileObject($this->queryDir() . "/$line", $cache, $quicklog);
+                if (is_a($fl, 'PEAR_Error')) {
+                    return $fl;
                 } else {
-                    $this->files[] = &$this->rep->getFileObject($this->queryDir() . "/$line", $cache, $quicklog);
+                    $this->files[] = &$fl;
                 }
             }
         }
 
         pclose($dir);
 
-        if (count($errors)) {
+        if ($errors) {
             return PEAR::raiseError(implode("\n", $errors));
         }
 
@@ -463,18 +490,16 @@ class VC_File_svn extends VC_File {
          * The version of the cached data. Increment this whenever the
          * internal storage format changes, such that we must
          * invalidate prior cached data.
-         *
-         * @var integer $cacheVersion
          */
         $cacheVersion = 2;
-        $cacheId = $filename . '_f' . (int)$quicklog . '_v' . $cacheVersion;
+        $cacheId = $rep->sourceroot() . '_n' . $filename . '_f' . (int)$quicklog . '_v' . $cacheVersion;
 
         if ($cache &&
             // The file is cached for one hour no matter what, because
             // there is no way to determine with Subversion the time
             // the file last changed.
-            $cache->exists($cacheId, time() - 360)) {
-            $fileOb = unserialize($cache->get($cacheId, time() - 360));
+            $cache->exists($cacheId, 3600)) {
+            $fileOb = unserialize($cache->get($cacheId, 3600));
             $fileOb->setRepository($rep);
         } else {
             $fileOb = &new VC_File_svn($rep, $filename, $quicklog);
@@ -623,17 +648,22 @@ class VC_File_svn extends VC_File {
      * and dates of the file.
      *
      * @return mixed boolean            True on success,
-     *               object PEAR_Error  On error.
+     *               PEAR_Error         On error.
      */
     function getBrowseInfo()
     {
         /* This doesn't work; need to find another way to simply
-		 * request the most recent revision:
-		 *
-		 * $flag = $this->quicklog ? '-r HEAD ' : ''; */
-		$flag = '';
-        $cmd = $this->rep->getPath('svn') . ' log -v ' . $flag . $this->queryFullPath() . ' 2>&1';
+         * request the most recent revision:
+         *
+         * $flag = $this->quicklog ? '-r HEAD ' : ''; */
+        $flag = '';
+        $Q = VC_WINDOWS ? '"' : "'";
+        $cmd = $this->rep->getPath('svn') . ' log -v ' . $flag . $Q . str_replace($Q, '\\' . $Q, $this->queryFullPath()) . $Q . ' 2>&1';
         $pipe = popen($cmd, 'r');
+        if (!$pipe) {
+            return PEAR::raiseError('Failed to execute svn log: ' . $cmd);
+        }
+
         fgets($pipe);
         while (!feof($pipe)) {
             $log = &new VC_Log_svn($this->rep, $this);
@@ -644,9 +674,9 @@ class VC_File_svn extends VC_File {
                 $this->revs[] = $rev;
             }
 
-			if ($this->quicklog) {
-				break;
-			}
+            if ($this->quicklog) {
+                break;
+            }
         }
 
         pclose($pipe);
@@ -716,7 +746,7 @@ class VC_Log_svn {
             return false;
         }
 
-        if (preg_match('/^r([0-9]*) \| ([^ ]*) \| (.*) \(.*\) \| ([0-9]*) lines?$/', $line, $matches)) {
+        if (preg_match('/^r([0-9]*) \| (.*?) \| (.*) \(.*\) \| ([0-9]*) lines?$/', $line, $matches)) {
             $this->rev = $matches[1];
             $this->author = $matches[2];
             $this->date = strtotime($matches[3]);
@@ -823,18 +853,16 @@ class VC_Patchset_svn {
          * The version of the cached data. Increment this whenever the
          * internal storage format changes, such that we must
          * invalidate prior cached data.
-         *
-         * @var integer $cacheVersion
          */
         $cacheVersion = 1;
-        $cacheId = $filename . '_f_v' . $cacheVersion;
+        $cacheId = $rep->sourceroot() . '_n' . $filename . '_f_v' . $cacheVersion;
 
         if ($cache &&
             // The file is cached for one hour no matter what, because
             // there is no way to determine with svn the time the file
             // last changed.
-            $cache->exists($cacheId, time() - 360)) {
-            $psOb = unserialize($cache->get($cacheId, time() - 360));
+            $cache->exists($cacheId, 3600)) {
+            $psOb = unserialize($cache->get($cacheId, 3600));
         } else {
             $psOb = &new VC_Patchset_svn($filename);
 
