@@ -1,3 +1,4 @@
+
 <?php
 
 include_once 'Log.php';
@@ -6,13 +7,12 @@ include_once 'Log.php';
 define('IMSP_CRLF', "\r\n");
 define('IMSP_DEFAULT_RESPONSE_LENGTH',512);
 define('IMSP_OCTET_COUNT', "/({)([0-9]{1,})(\}$)/");
-define('IMSP_MUST_USE_LITERAL', "/[^a-z0-9\s\-,]/i");
+define('IMSP_MUST_USE_LITERAL', "/[\W]/i");
 
 // These define regExp that should match the respective server
 // response strings.
 define('IMSP_CONNECTION_OK', "/^\* OK/");
 define('IMSP_COMMAND_CONTINUATION_RESPONSE', "/^\+/");
-define('IMSP_CAPABILITY_RESPONSE', "/^\* CAPABILITY/");
 
 // Exit code values
 define('IMSP_EXIT_LOGIN_FAILED', 'Login to IMSP host failed.');
@@ -26,41 +26,50 @@ define('IMSP_NO_CONTINUATION_RESPONSE', 'Did not receive expexted command contin
 /**
  * The Net_IMSP class provides a common interface to an IMSP server .
  *
- * Required parameters:
- * =========================
- * 'server' -- Hostname of IMSP server.
- * 'port'   -- Port of IMSP server.
+ * Required parameters:<pre>
+ *   'server'  Hostname of IMSP server.
+ *   'port'    Port of IMSP server.</pre>
  *
- * $Horde: framework/Net_IMSP/IMSP.php,v 1.13.10.1 2005/01/03 12:19:08 jan Exp $
+ * $Horde: framework/Net_IMSP/IMSP.php,v 1.13.10.13 2005/09/30 03:24:33 selsky Exp $
  *
- * Copyright 2003-2005 Michael Rubinsky <mike@theupstairsroom.com>
+ * Copyright 2003-2005 Michael Rubinsky <mrubinsk@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @version $Revision: 1.13.10.1 $
- * @author  Michael Rubinsky <mike@theupstairsroom.com>
+ * @author  Michael Rubinsky <mrubinsk@horde.org>
  * @package Net_IMSP
  */
 class Net_IMSP {
 
     /**
      * String containing name/IP address of imsp host.
-     * @var string $imsp_server
+     *
+     * @var string
      */
     var $imsp_server                = 'localhost';
 
     /**
      * String containing port for imsp server.
-     * @var string $imsp_port
+     *
+     * @var string
      */
     var $imsp_port                  = '406';
 
     /**
      * Boolean to set if we should write to a log, if one is set up.
-     * @var boolean $logEnabled
+     *
+     * @var boolean
      */
     var $logEnabled                 = true;
+    /**
+     * String buffer containing the last raw NO or BAD response from the
+     * server.
+     *
+     * @var string
+     */
+    var $lastRawError              = '';
+
 
     // Private Declarations
     var $_commandPrefix             = 'A';
@@ -76,7 +85,6 @@ class Net_IMSP {
     /**
      * Constructor function.
      *
-     * @access public
      * @param array $params Hash containing server parameters.
      */
     function Net_IMSP($params)
@@ -95,7 +103,6 @@ class Net_IMSP {
      * Initialization function to be called after object is returned.  This
      * allows errors to occur and not break the script.
      *
-     * @access public
      * @return mixed  True on success PEAR_Error on connection failure.
      */
     function init()
@@ -106,18 +113,17 @@ class Net_IMSP {
             return $result;
         }
         $this->writeToLog('Initializing Net_IMSP object.', __FILE__, __LINE__,
-                          PEAR_LOG_DEBUG);
+                          PEAR_LOG_INFO);
         return true;
     }
 
     /**
      * Logs out of the server and closes the IMSP stream
-     *
-     *@access public
      */
     function logout()
     {
-        $this->writeToLog('Closing Connection.');
+        $this->writeToLog('Closing IMSP Connection.', __FILE__, __LINE__,
+                          PEAR_LOG_INFO);
         $command_string = 'LOGOUT';
         $result = $this->imspSend($command_string);
         if (is_a($result, 'PEAR_Error')) {
@@ -132,29 +138,27 @@ class Net_IMSP {
     /**
      * Returns the raw capability response from the server.
      *
-     * @access public
      * @return string  The raw capability response.
      */
     function capability()
     {
         $command_string = 'CAPABILITY';
-
         $result = $this->imspSend($command_string);
         if (is_a($result, 'PEAR_Error')) {
             return $result;
         } else {
             $server_response = $this->imspReceive();
-
-            if (preg_match(IMSP_CAPABILITY_RESPONSE, $server_response)) {
-                $capability = preg_replace(IMSP_CAPABILITY_RESPONSE,
+            if (preg_match("/^\* CAPABILITY/", $server_response)) {
+                $capability = preg_replace("/^\* CAPABILITY/",
                                            '', $server_response);
                 $server_response = $this->imspReceive(); //OK
 
                 if (!$server_response == 'OK') {
                     return $this->imspError(IMSP_UNEXPECTED_RESPONSE,
-                                            __FILE__,__LINE__);
+                                            __FILE__, __LINE__);
                 } else {
-                    $this->writeToLog('CAPABILITY completed OK');
+                    $this->writeToLog('CAPABILITY completed OK', __FILE__,
+                                      __LINE__, PEAR_LOG_INFO);
                     return $capability;
                 }
             }
@@ -164,34 +168,27 @@ class Net_IMSP {
     /**
      * Attempts to open an IMSP socket with the server.
      *
-     * @access public
      * @return mixed  True on success PEAR_Error on failure.
      */
     function imspOpen()
     {
         $fp = @fsockopen($this->imsp_server, $this->imsp_port);
-
-        // Check for failure
         if (!$fp) {
             return $this->imspError(IMSP_CONNECTION_FAILURE, __FILE__,
                                     __LINE__);
         }
-
         $this->_stream = $fp;
         $server_response = $this->imspReceive();
-
         if (!preg_match(IMSP_CONNECTION_OK, $server_response)) {
             fclose($fp);
-            return $this->imspError(IMSP_UNEXPECTED_RESPONSE,__FILE__,__LINE__);
+            return $this->imspError(IMSP_UNEXPECTED_RESPONSE, __FILE__, __LINE__);
         }
-
         return true;
     }
 
     /**
      * Attempts to send a command to the server.
      *
-     * @access public
      * @param string  $commandText Text to send to the server.
      * @param boolean $includeTag  Determines if command tag is prepended.
      * @param boolean  $sendCRLF   Determines if CRLF is appended.
@@ -201,8 +198,8 @@ class Net_IMSP {
     {
         $command_text = '';
 
-        if (!$this->_stream){
-            return $this->imspError(IMSP_CONNECTION_FAILURE,__FILE__,__LINE__);
+        if (!$this->_stream) {
+            return $this->imspError(IMSP_CONNECTION_FAILURE, __FILE__, __LINE__);
         }
 
         if ($includeTag) {
@@ -217,10 +214,10 @@ class Net_IMSP {
         }
 
         $this->writeToLog('To: ' . $command_text, __FILE__,
-                          __LINE__,PEAR_LOG_DEBUG);
+                          __LINE__, PEAR_LOG_DEBUG);
 
         if (!fputs($this->_stream, $command_text)) {
-            return $this->imspError(IMSP_CONNECTION_FAILURE,__FILE__,__LINE__);
+            return $this->imspError(IMSP_CONNECTION_FAILURE, __FILE__, __LINE__);
         } else {
             return true;
         }
@@ -229,48 +226,49 @@ class Net_IMSP {
     /**
      * Receives a single CRLF terminated server response string
      *
-     * @access public
      * @return mixed 'NO', 'BAD', 'OK', raw response or PEAR_Error.
      */
     function imspReceive()
     {
-        if (!$this->_stream){
-            return $this->imspError(IMSP_CONNECTION_FAILURE,__FILE__,__LINE__);
+        if (!$this->_stream) {
+            return $this->imspError(IMSP_CONNECTION_FAILURE, __FILE__, __LINE__);
         }
-
         $result = fgets($this->_stream, IMSP_DEFAULT_RESPONSE_LENGTH);
-
         if (!$result) {
             return $this->imspError(IMSP_UNEXPECTED_RESPONSE,
-                                    __FILE__,__LINE__);
+                                    __FILE__, __LINE__);
+        }
+        $meta = stream_get_meta_data($this->_stream);
+        if ($meta['timed_out']) {
+            return $this->imspError(IMSP_CONNECTION_FAILURE . ': Connection timed out!', 
+                                    __FILE__, __LINE__);
         }
 
         $server_response = trim($result);
         $this->writeToLog('From: ' . $server_response, __FILE__,
                           __LINE__, PEAR_LOG_DEBUG);
 
-        /**
-         * Parse out the response:
+        /* Parse out the response:
          * First make sure that this is not for a previous command.
          * If it is, it means we did not read all the server responses from
-         * the last command...read them now, but throw an error.
-         */
+         * the last command...read them now, but throw an error. */
         while (preg_match("/^" . $this->_lastCommandTag
                           ."/", $server_response)) {
             $server_response =
-                trim(fgets($this->_stream,IMSP_DEFAULT_RESPONSE_LENGTH));
+                trim(fgets($this->_stream, IMSP_DEFAULT_RESPONSE_LENGTH));
             $this->imspError(IMSP_UNEXPECTED_RESPONSE . ": $server_response",
-                             __FILE__,__LINE__);
+                             __FILE__, __LINE__);
         }
 
         $currentTag = $this->_tag;
-
         if (preg_match("/^" . $currentTag . " NO/", $server_response)) {
+            $this->lastRawError = $server_response;
             return 'NO';
         }
 
         if (preg_match("/^" . $currentTag . " BAD/", $server_response)) {
-            $this->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
+            $this->imspError(IMSP_SYNTAX_ERROR, __FILE__, __LINE__);
+            $this->lastRawError = $server_response;
             return 'BAD';
         }
 
@@ -278,11 +276,9 @@ class Net_IMSP {
             return 'OK';
         }
 
-        /**
-         * If it was not a 'NO', 'BAD' or 'OK' response,
+        /* If it was not a 'NO', 'BAD' or 'OK' response,
          * then it's up to the calling function to decide
-         * what to do with it.
-         */
+         * what to do with it. */
         return $server_response;
     }
 
@@ -290,13 +286,12 @@ class Net_IMSP {
      * Retrieves CRLF terminated response from server and splits it into
      * an array delimited by a <space>.
      *
-     * @access public
      * @return array result from split().
      */
     function getServerResponseChunks()
     {
         $server_response =
-            trim(fgets($this->_stream,IMSP_DEFAULT_RESPONSE_LENGTH));
+            trim(fgets($this->_stream, IMSP_DEFAULT_RESPONSE_LENGTH));
         $chunks = split(' ', $server_response);
         return $chunks;
     }
@@ -305,9 +300,9 @@ class Net_IMSP {
      * Receives fixed number of bytes from imsp socket. Used when
      * server returns a string literal.
      *
-     * @access public
-     * @param int $length Number of bytes to read from socket.
-     * @return string Text of string literal.
+     * @param integer $length  Number of bytes to read from socket.
+     *
+     * @return string  Text of string literal.
      */
     function receiveStringLiteral($length)
     {
@@ -330,10 +325,8 @@ class Net_IMSP {
     }
 
     /**
-     * Determines if a string needs to be quoted before sending to the
-     * server.
+     * Determines if a string needs to be quoted before sending to the server.
      *
-     * @access public
      * @param string $string  String to be tested.
      * @return string Original string quoted if needed.
      */
@@ -350,11 +343,9 @@ class Net_IMSP {
      * Raises an 'imsp' error.  Basically, only writes
      * error out to the horde logfile and returns PEAR_Error
      *
-     *
-     * @param string $err  Either a PEAR_Error object or
-     *                     text to write to log.
-     * @param string $file File name where error occured.
-     * @param int $line Line number where error occured.
+     * @param string $err    Either PEAR_Error object or text to write to log.
+     * @param string $file   File name where error occured.
+     * @param integer $line  Line number where error occured.
      */
     function imspError($err = '', $file=__FILE__, $line=__LINE__)
     {
@@ -365,7 +356,6 @@ class Net_IMSP {
         }
 
         $this->writeToLog($log_text, $file, $line, PEAR_LOG_ERR);
-
         if (is_a($err, 'PEAR_Error')) {
             return $err;
         } else {
@@ -376,11 +366,10 @@ class Net_IMSP {
     /**
      * Writes a message to the imsp logfile.
      *
-     * @access public
-     * @param string $message Text to write.
+     * @param string $message  Text to write.
      */
-    function writeToLog($message, $file=__FILE__,
-                        $line=__LINE__, $priority=PEAR_LOG_INFO)
+    function writeToLog($message, $file = __FILE__,
+                        $line = __LINE__, $priority = PEAR_LOG_INFO)
     {
         if (($this->logEnabled) && ($this->_logSet)) {
             if ($priority > $this->_logLevel) {
@@ -401,8 +390,7 @@ class Net_IMSP {
     /**
      * Creates a new Log object based on $params
      *
-     * @access public
-     * @param array $params Log object parameters.
+     * @param  array  $params Log object parameters.
      * @return mixed  True on success or PEAR_Error on failure.
      */
     function setLogger($params)
@@ -419,7 +407,6 @@ class Net_IMSP {
             $this->_logger = &$logger;
             $this->logEnabled = true;
             $this->_writeLogBuffer();
-
             return true;
         }
     }
@@ -445,15 +432,13 @@ class Net_IMSP {
      * Attempts to create a Net_IMSP object based on $driver.
      * Must be called as $imsp = &Net_IMSP::factory($driver, $params);
      *
-     * @access public
-     * @param string $driver Type of Net_IMSP object to return.
-     * @param mixed $params  Any parameters needed by the Net_IMSP object.
+     * @param  string $driver Type of Net_IMSP object to return.
+     * @param  mixed  $params  Any parameters needed by the Net_IMSP object.
      * @return mixed  The requested Net_IMSP object or PEAR_Error on failure.
      */
     function &factory($driver, $params)
     {
         $driver = basename($driver);
-
         if (empty($driver) || $driver == 'none') {
             return $dvr = &new Net_IMSP($params);
         }
@@ -473,14 +458,13 @@ class Net_IMSP {
      * doesn't exist.
      * Must be called as $imsp = &Net_IMSP::singleton($driver, $params);
      *
-     * @param string $driver Type of Net_IMSP object to return.
-     * @params mixed $params Any parameters needed by the Net_IMSP object.
-     * @return mixed Reference to the Net_IMSP object or PEAR_Error on failure.
+     * @param  string $driver Type of Net_IMSP object to return.
+     * @param  mixed  $params Any parameters needed by the Net_IMSP object.
+     * @return mixed  Reference to the Net_IMSP object or PEAR_Error on failure.
      */
     function &singleton($driver, $params)
     {
         static $instances;
-
         if (!isset($instances)) {
             $instances = array();
         }
