@@ -2,22 +2,20 @@
 /**
  * The Net_IMSP_Auth_plaintext class for IMSP authentication.
  *
- * Required parameters:
- * ====================
- * 'username'       -- Username to logon to IMSP server as.
- * 'password'       -- Password for current user.
- * 'server'         -- The hostname of the IMSP server.
- * 'port'           -- The port of the IMSP server.
+ * Required parameters:<pre>
+ *   'username'  Username to logon to IMSP server as.
+ *   'password'  Password for current user.
+ *   'server'    The hostname of the IMSP server.
+ *   'port'      The port of the IMSP server.</pre>
  *
- * $Horde: framework/Net_IMSP/IMSP/Auth/plaintext.php,v 1.7.10.1 2005/01/03 12:19:08 jan Exp $
+ * $Horde: framework/Net_IMSP/IMSP/Auth/plaintext.php,v 1.7.10.5 2005/04/26 23:35:29 selsky Exp $
  *
- * Copyright 2003-2005 Michael Rubinsky <mike@theupstairsroom.com>
+ * Copyright 2003-2005 Michael Rubinsky <mrubinsk@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @version $Revision: 1.7.10.1 $
- * @author  Michael Rubinsky <mike@theupstairsroom.com>
+ * @author  Michael Rubinsky <mrubinsk@horde.org>
  * @package Net_IMSP
  */
 class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
@@ -27,13 +25,13 @@ class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
      * authentication code.
      *
      * @access private
-     * @param mixed $params Hash of IMSP parameters.
+     * @param  mixed  $params Hash of IMSP parameters.
      * @return mixed  Net_IMSP object connected to server if successful,
      *                PEAR_Error on failure.
      */
     function &_authenticate($params)
     {
-        $imsp = &Net_IMSP::singleton('none',$params);
+        $imsp = &Net_IMSP::singleton('none', $params);
         $result = $imsp->init();
         if (is_a($result, 'PEAR_Error')) {
             return $result;
@@ -42,16 +40,15 @@ class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
          $userId = $params['username'];
          $credentials = $params['password'];
 
-        // Start the command.
+        /* Start the command. */
         $result = $imsp->imspSend('LOGIN ', true, false);
         if (is_a($result, 'PEAR_Error')) {
             return $result;
         }
 
-        // Username as a {}?
+        /* Username as a {}? */
         if (preg_match(IMSP_MUST_USE_LITERAL, $userId)) {
             $biUser = sprintf('{%d}', strlen($userId));
-
             $result = $imsp->imspSend($biUser, false, true);
             if (is_a($result, 'PEAR_Error')) {
                 return $result;
@@ -61,7 +58,7 @@ class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
                             $imsp->imspReceive())) {
 
                 return $imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                        __FILE__,__LINE__);
+                                        __FILE__, __LINE__);
             }
         }
 
@@ -70,11 +67,11 @@ class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
             return $result;
         }
 
-        //Don't want to log the password!
+        /* Don't want to log the password! */
         $logValue = $imsp->logEnabled;
         $imsp->logEnabled = false;
 
-        // Pass as {}?
+        /* Pass as {}? */
         if (preg_match(IMSP_MUST_USE_LITERAL, $credentials)) {
             $biPass = sprintf('{%d}', strlen($credentials));
             $result = $imsp->imspSend($biPass, false, true);
@@ -85,7 +82,7 @@ class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $imsp->imspReceive())) {
                 return $imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                        __FILE__,__LINE__);
+                                        __FILE__, __LINE__);
             }
         }
 
@@ -94,7 +91,7 @@ class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
             return $result;
         }
 
-        // Restore the logging boolean.
+        /* Restore the logging boolean. */
         $imsp->logEnabled = $logValue;
 
         $server_response = $imsp->imspReceive();
@@ -103,10 +100,29 @@ class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
         }
 
         if ($server_response != 'OK') {
-            return $imsp->imspError(IMSP_EXIT_LOGIN_FAILED,__FILE__,__LINE__);
+            return $imsp->imspError(IMSP_EXIT_LOGIN_FAILED, __FILE__, __LINE__);
         }
 
         return $imsp;
     }
 
+    /**
+     * Force a logout command to the imsp stream.
+     *
+     */
+    function logout()
+    {
+        $this->_imsp->logout();
+    }
+
+    /**
+     * Return the driver type
+     *
+     * @return string the type of this IMSP_Auth driver
+     */
+     function getDriverType()
+     {
+         return 'plaintext';
+     }
+
 }
