@@ -2,65 +2,64 @@
 
 require_once 'Net/IMSP/Auth.php';
 
-// Constants
-define('IMSP_GETOPTION_RESPONSE', "/^\* OPTION/");
-
 /**
  * Net_IMSP_Options Class - provides an interface to IMSP server-based
  * options storage.
  *
- * Required parameters:
- * ====================
- * 'username'       -- Username to logon to IMSP server as.
- * 'password'       -- Password for current user.
- * 'auth_method'    -- The authentication method to use to login.
- * 'server'         -- The hostname of the IMSP server.
- * 'port'           -- The port of the IMSP server.
+ * Required parameters:<pre>
+ *   'username'     Username to logon to IMSP server as.
+ *   'password'     Password for current user.
+ *   'auth_method'  The authentication method to use to login.
+ *   'server'       The hostname of the IMSP server.
+ *   'port'         The port of the IMSP server.</pre>
  *
- * $Horde: framework/Net_IMSP/IMSP/Options.php,v 1.3.2.1 2005/01/03 12:19:08 jan Exp $
+ * $Horde: framework/Net_IMSP/IMSP/Options.php,v 1.3.2.10 2005/09/29 00:50:38 selsky Exp $
  *
- * Copyright 2004-2005 Michael Rubinsky <mike@theupstairsroom.com>
+ * Copyright 2004-2005 Michael Rubinsky <mrubinsk@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @version $Revision: 1.3.2.1 $
- * @author  Michael Rubinsky <mike@theupstairsroom.com>
+ * @author  Michael Rubinsky <mrubinsk@horde.org>
  * @package Net_IMSP
  */
 class Net_IMSP_Options {
 
+    /**
+     * Net_IMSP object.
+     *
+     * @var Net_IMSP
+     */
     var $_imsp;
-    var $user = '';
-    var $pass = '';
-    var $auth_method = '';
-    var $server = '';
-    var $port = '';
-    var $params;
+
+    /**
+     * Parameter list.
+     *
+     * @var array
+     */
+    var $_params;
 
     /**
      * Constructor function.
      *
-     * @access public
-     * @param array $params Hash containing IMSP parameters.
+     * @param array $params  Hash containing IMSP parameters.
      */
     function Net_IMSP_Options($params)
     {
-        $this->params = $params;
+        $this->_params = $params;
     }
 
     /**
      * Initialization function to be called after object is returned.
      * This allows errors to occur and not break the script.
      *
-     * @access public
-     * @return mixed True on success PEAR_Error on failure.
+     * @return mixed  True on success PEAR_Error on failure.
      */
     function init()
     {
         if (!isset($this->_imsp)) {
-            $auth = &Net_IMSP_Auth::singleton($this->params['auth_method']);
-            $this->_imsp = $auth->authenticate($this->params);
+            $auth = &Net_IMSP_Auth::singleton($this->_params['auth_method']);
+            $this->_imsp = $auth->authenticate($this->_params);
         }
 
         if (is_a($this->_imsp, 'PEAR_Error')) {
@@ -74,9 +73,8 @@ class Net_IMSP_Options {
     /**
      * Function sends a GET command to IMSP server and retrieves values.
      *
-     * @access public
-     * @param string $optionName Name of option to retrieve. Accepts '*'
-     *                           as wild card.
+     * @param  string $optionName Name of option to retrieve. Accepts '*'
+     *                            as wild card.
      * @return mixed  Associative array containing option=>value pairs or
      *                PEAR_Error.
      */
@@ -93,22 +91,22 @@ class Net_IMSP_Options {
             return $server_response;
         }
 
-        while (preg_match(IMSP_GETOPTION_RESPONSE,$server_response)){
+        while (preg_match("/^\* OPTION/", $server_response)) {
             /* First, check for a {}. */
-            if (preg_match(IMSP_OCTET_COUNT, $server_response, $tempArray)){
-                $temp = split(' ', $server_response);
+            if (preg_match(IMSP_OCTET_COUNT, $server_response, $tempArray)) {
+                $temp = explode(' ', $server_response);
                 $options[$temp[2]] = $this->_imsp->receiveStringLiteral($tempArray[2]);
-                $this->_imsp->imspReceive(); // [READ WRITE]
+                $this->_imsp->imspReceive();
             } else {
-                $temp = split(' ', $server_response);
+                $temp = explode(' ', $server_response);
                 $options[$temp[2]] = trim($temp[3]);
                 $i = 3;
                 $lastChar = "";
                 $nextElement = trim($temp[3]);
-                // Was the value quoted and spaced?
+
+                /* Was the value quoted and spaced? */
                 if ((substr($nextElement,0,1) == '"') &&
                     (substr($nextElement,strlen($nextElement) - 1, 1) != '"')) {
-
                     do {
                         $nextElement = $temp[$i+1];
                         $lastChar = substr($nextElement,
@@ -132,37 +130,36 @@ class Net_IMSP_Options {
                 }
             }
             $server_response = $this->_imsp->imspReceive();
-            if (is_a($server_response, 'PEAR_Error')){
+            if (is_a($server_response, 'PEAR_Error')) {
                 return $server_response;
             }
         }
 
         if ($server_response != 'OK') {
             return $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE,
-                                           __FILE__,__LINE__);
+                                           __FILE__, __LINE__);
         }
 
-        $this->_imsp->writeToLog('GET command OK.', '', '', PEAR_LOG_DEBUG);
+        $this->_imsp->writeToLog('GET command OK.', __FILE__, __LINE__, PEAR_LOG_DEBUG);
         return $options;
     }
 
     /**
      * Function sets an option value on the IMSP server.
      *
-     * @access public
      * @param string $optionName Name of option to set.
      * @param string $optionValue Value to assign.
      * @return mixed True or PEAR_Error.
      */
     function set($optionName, $optionValue)
     {
-        // Send the beginning of the command.
+        /* Send the beginning of the command. */
         $result = $this->_imsp->imspSend("SET $optionName ", true, false);
 
-        // Send $optionValue as a literal {}?
+        /* Send $optionValue as a literal {}? */
         if (preg_match(IMSP_MUST_USE_LITERAL, $optionValue)) {
-            $biValue = sprintf("{%d}",strlen($optionValue));
-            $result = $this->_imsp->imspSend($biValue,false,true);
+            $biValue = sprintf("{%d}", strlen($optionValue));
+            $result = $this->_imsp->imspSend($biValue, false, true);
             if (is_a($result, 'PEAR_Error')) {
                 return $result;
             }
@@ -170,11 +167,11 @@ class Net_IMSP_Options {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__,__LINE__);
+                                               __FILE__, __LINE__);
             }
         }
 
-        // Now send the rest of the command.
+        /* Now send the rest of the command. */
         $result = $this->_imsp->imspSend($optionValue, false, true);
         if (is_a($result, 'PEAR_Error')) {
             return $result;
@@ -185,18 +182,18 @@ class Net_IMSP_Options {
         if (is_a($server_response, 'PEAR_Error')) {
             return $server_response;
         } elseif ($server_response != 'OK') {
-            return $this->_imsp->imspError('The option could not be set on the IMSP server.',__FILE__, __LINE__);
+            return $this->_imsp->imspError('The option could not be set on the IMSP server.', __FILE__, __LINE__);
         }
 
-        $this->_imsp->writeToLog('SET command OK.', '', '', PEAR_LOG_DEBUG);
+        $this->_imsp->writeToLog('SET command OK.', __FILE__, __LINE__, PEAR_LOG_DEBUG);
         return true;
     }
 
     /**
      * Sets the log information in the Net_IMSP object.
      *
-     * @access public
-     * @param array The log parameters.
+     * @param array $params  The log parameters.
+     *
      * @return mixed  True on success PEAR_Error on failure.
      */
     function setLogger($params)
@@ -207,5 +204,10 @@ class Net_IMSP_Options {
             return $this->_imsp->imspError('The IMSP log could not be initialized.');
         }
     }
+    function logout()
+    {
+        $this->_imsp->logout();
+    }
+
 
 }
