@@ -6,12 +6,12 @@ require_once 'Log.php';
 /**
  * VFS API for abstracted file storage and access.
  *
- * $Horde: framework/VFS/VFS.php,v 1.69.4.1 2005/01/03 12:19:20 jan Exp $
+ * $Horde: framework/VFS/VFS.php,v 1.69.4.6 2005/08/03 00:17:18 slusarz Exp $
  *
  * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ * See the enclosed file COPYING for license information (LGPL). If you did
+ * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @package VFS
@@ -22,24 +22,22 @@ class VFS {
     /**
      * Hash containing connection parameters.
      *
-     * @var array $_params
+     * @var array
      */
     var $_params = array();
 
     /**
-     * List of additional credentials required for this VFS backend
-     * (example: For FTP, we need a username and password to log in to
-     * the server with).
+     * List of additional credentials required for this VFS backend (example:
+     * For FTP, we need a username and password to log in to the server with).
      *
-     * @var array $_credentials
+     * @var array
      */
     var $_credentials = array();
 
     /**
-     * List of permissions and if they can be changed in this VFS
-     * backend.
+     * List of permissions and if they can be changed in this VFS backend.
      *
-     * @var array $_permissions
+     * @var array
      */
     var $_permissions = array(
         'owner' => array('read' => false, 'write' => false, 'execute' => false),
@@ -50,25 +48,22 @@ class VFS {
      * A PEAR Log object. If present, will be used to log errors and
      * informational messages about VFS activity.
      *
-     * @var Log $_logger
+     * @var Log
      */
     var $_logger = null;
 
     /**
-     * The log level to use - messages with a higher log level than
-     * configured here will not be logged. Defaults to only logging
-     * errors or higher.
+     * The log level to use - messages with a higher log level than configured
+     * here will not be logged. Defaults to only logging errors or higher.
      *
-     * @var integer $_logLevel
+     * @var integer
      */
     var $_logLevel = PEAR_LOG_ERR;
 
     /**
-     * Constructs a new VFS object.
+     * Constructor.
      *
-     * @access public
-     *
-     * @param optional array $params  A hash containing connection parameters.
+     * @param array $params  A hash containing connection parameters.
      */
     function VFS($params = array())
     {
@@ -79,13 +74,11 @@ class VFS {
     }
 
     /**
-     * Check the credentials that we have by calling _connect(), to
-     * see if there is a valid login.
+     * Checks the credentials that we have by calling _connect(), to see if
+     * there is a valid login.
      *
-     * @access public
-     *
-     * @return mixed  True on success, PEAR_Error describing the problem
-     *                if the credentials are invalid.
+     * @return mixed  True on success, PEAR_Error describing the problem if the
+     *                credentials are invalid.
      */
     function checkCredentials()
     {
@@ -93,12 +86,9 @@ class VFS {
     }
 
     /**
-     * Set configuration parameters.
+     * Sets configuration parameters.
      *
-     * @access public
-     *
-     * @param optional array $params  An associative array:
-     *                                KEY: param name, VAL: param value
+     * @param array $params  An associative array with parameter names as keys.
      */
     function setParams($params = array())
     {
@@ -110,8 +100,6 @@ class VFS {
     /**
      * Returns configuration parameters.
      *
-     * @access public
-     *
      * @param string $name  The parameter to return.
      *
      * @return mixed  The parameter value or null if it doesn't exist.
@@ -122,9 +110,8 @@ class VFS {
     }
 
     /**
-     * Log a message if a PEAR Log object is available, and the
-     * message's priority is lower than or equal to the configured log
-     * level.
+     * Logs a message if a PEAR Log object is available, and the message's
+     * priority is lower than or equal to the configured log level.
      *
      * @param mixed   $message   The message to be logged.
      * @param integer $priority  The message's priority.
@@ -157,8 +144,7 @@ class VFS {
     }
 
     /**
-     * Set the PEAR Log object used to log informational or error
-     * messages.
+     * Sets the PEAR Log object used to log informational or error messages.
      *
      * @param Log &$logger  The Log object to use.
      */
@@ -175,16 +161,14 @@ class VFS {
     }
 
     /**
-     * Retrieve a file from the VFS.
+     * Retrieves a file from the VFS.
      *
-     * @access public
+     * @abstract
      *
      * @param string $path  The pathname to the file.
      * @param string $name  The filename to retrieve.
      *
      * @return string The file data.
-     *
-     * @abstract
      */
     function read($path, $name)
     {
@@ -192,19 +176,17 @@ class VFS {
     }
 
     /**
-     * Store a file in the VFS.
-     *
-     * @access public
-     *
-     * @param string $path                  The path to store the file in.
-     * @param string $name                  The filename to use.
-     * @param string $tmpFile               The temporary file containing the
-     *                                      data to be stored.
-     * @param optional boolean $autocreate  Automatically create directories?
-     *
-     * @return mixed  True on success or a PEAR_Error object on failure.
+     * Stores a file in the VFS.
      *
      * @abstract
+     *
+     * @param string $path         The path to store the file in.
+     * @param string $name         The filename to use.
+     * @param string $tmpFile      The temporary file containing the data to
+     *                             be stored.
+     * @param boolean $autocreate  Automatically create directories?
+     *
+     * @return mixed  True on success or a PEAR_Error object on failure.
      */
     function write($path, $name, $tmpFile, $autocreate = false)
     {
@@ -212,17 +194,32 @@ class VFS {
     }
 
     /**
-     * Moves a file through the backend.
-     *
-     * @access public
-     *
-     * @param string $path  The path to store the file in.
-     * @param string $name  The filename to use.
-     * @param string $dest  The destination of the file.
-     *
-     * @return mixed  True on success or a PEAR_Error object on failure.
+     * Stores a file in the VFS from raw data.
      *
      * @abstract
+     *
+     * @param string $path         The path to store the file in.
+     * @param string $name         The filename to use.
+     * @param string $data         The file data.
+     * @param boolean $autocreate  Automatically create directories?
+     *
+     * @return mixed  True on success or a PEAR_Error object on failure.
+     */
+    function writeData($path, $name, $data, $autocreate = false)
+    {
+        return PEAR::raiseError(_("Not supported."));
+    }
+
+    /**
+     * Moves a file through the backend.
+     *
+     * @abstract
+     *
+     * @param string $path  The path of the original file.
+     * @param string $name  The name of the original file.
+     * @param string $dest  The destination file name.
+     *
+     * @return mixed  True on success or a PEAR_Error object on failure.
      */
     function move($path, $name, $dest)
     {
@@ -232,15 +229,13 @@ class VFS {
     /**
      * Copies a file through the backend.
      *
-     * @access public
+     * @abstract
      *
-     * @param string $path  The path to store the file in.
-     * @param string $name  The filename to use.
-     * @param string $dest  The destination of the file.
+     * @param string $path  The path of the original file.
+     * @param string $name  The name of the original file.
+     * @param string $dest  The name of the destination directory.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
-     *
-     * @abstract
      */
     function copy($path, $name, $dest)
     {
@@ -248,35 +243,14 @@ class VFS {
     }
 
     /**
-     * Store a file in the VFS from raw data.
-     *
-     * @access public
-     *
-     * @param string $path                  The path to store the file in.
-     * @param string $name                  The filename to use.
-     * @param string $data                  The file data.
-     * @param optional boolean $autocreate  Automatically create directories?
-     *
-     * @return mixed  True on success or a PEAR_Error object on failure.
+     * Deletes a file from the VFS.
      *
      * @abstract
-     */
-    function writeData($path, $name, $data, $autocreate = false)
-    {
-        return PEAR::raiseError(_("Not supported."));
-    }
-
-    /**
-     * Delete a file from the VFS.
      *
-     * @access public
-     *
-     * @param string $path  The path to store the file in.
-     * @param string $name  The filename to use.
+     * @param string $path  The path to delete the file from.
+     * @param string $name  The filename to delete.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
-     *
-     * @abstract
      */
     function deleteFile($path, $name)
     {
@@ -284,9 +258,9 @@ class VFS {
     }
 
     /**
-     * Rename a file in the VFS.
+     * Renames a file in the VFS.
      *
-     * @access public
+     * @abstract
      *
      * @param string $oldpath  The old path to the file.
      * @param string $oldname  The old filename.
@@ -294,8 +268,6 @@ class VFS {
      * @param string $newname  The new filename.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
-     *
-     * @abstract
      */
     function rename($oldpath, $oldname, $newpath, $newname)
     {
@@ -303,12 +275,10 @@ class VFS {
     }
 
     /**
-     * Check if a given file/folder exists in a folder.
-     *
-     * @access public
+     * Returns if a given file or folder exists in a folder.
      *
      * @param string $path  The path to the folder.
-     * @param string $name  The file/folder name.
+     * @param string $name  The file or folder name.
      *
      * @return boolean  True if it exists, false otherwise.
      */
@@ -323,16 +293,14 @@ class VFS {
     }
 
     /**
-     * Create a folder in the VFS.
+     * Creates a folder in the VFS.
      *
-     * @access public
+     * @abstract
      *
-     * @param string $path  The path to the folder.
+     * @param string $path  The parent folder.
      * @param string $name  The name of the new folder.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
-     *
-     * @abstract
      */
     function createFolder($path, $name)
     {
@@ -340,29 +308,29 @@ class VFS {
     }
 
     /**
-     * Automatically create any necessary parent directories in the
+     * Automatically creates any necessary parent directories in the
      * specified $path.
      *
-     * @access public
-     *
      * @param string $path  The VFS path to autocreate.
      */
     function autocreatePath($path)
     {
         $dirs = explode('/', $path);
         if (is_array($dirs)) {
-            $cur = '';
+            $cur = '/';
             foreach ($dirs as $dir) {
-                if (!$this->isFolder($cur, $dir)) {
-                    $result = $this->createFolder($cur, $dir);
-                    if (is_a($result, 'PEAR_Error')) {
-                        return $result;
+                if (!empty($dir)) {
+                    if (!$this->isFolder($cur, $dir)) {
+                        $result = $this->createFolder($cur, $dir);
+                        if (is_a($result, 'PEAR_Error')) {
+                            return $result;
+                        }
                     }
+                    if ($cur != '/') {
+                        $cur .= '/';
+                    }
+                    $cur .= $dir;
                 }
-                if (!empty($cur)) {
-                    $cur .= '/';
-                }
-                $cur .= $dir;
             }
         }
 
@@ -370,12 +338,10 @@ class VFS {
     }
 
     /**
-     * Check if a given pathname is a folder.
+     * Checks if a given item is a folder.
      *
-     * @access public
-     *
-     * @param string $path  The path to the folder.
-     * @param string $name  The file/folder name.
+     * @param string $path  The parent folder.
+     * @param string $name  The item name.
      *
      * @return boolean  True if it is a folder, false otherwise.
      */
@@ -388,15 +354,13 @@ class VFS {
     /**
      * Deletes a folder from the VFS.
      *
-     * @access public
+     * @abstract
      *
-     * @param string $path                 The path of the folder to delete.
-     * @param string $name                 The name of the folder to delete.
-     * @param optional boolean $recursive  Force a recursive delete?
+     * @param string $path        The parent folder.
+     * @param string $name        The name of the folder to delete.
+     * @param boolean $recursive  Force a recursive delete?
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
-     *
-     * @abstract
      */
     function deleteFolder($path, $name, $recursive = false)
     {
@@ -406,8 +370,6 @@ class VFS {
     /**
      * Removes recursively all files and subfolders from the given folder.
      *
-     * @access public
-     *
      * @param string $path  The path of the folder to empty.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
@@ -441,16 +403,13 @@ class VFS {
     /**
      * Returns a file list of the directory passed in.
      *
-     * @access public
-     *
      * @param string $path        The path of the directory.
      * @param mixed $filter       String/hash to filter file/dirname on.
      * @param boolean $dotfiles   Show dotfiles?
      * @param boolean $dironly    Show only directories?
      * @param boolean $recursive  Return all directory levels recursively?
      *
-     * @return array  File list on success.
-     *                Returns PEAR_Error on failure.
+     * @return array  File list on success or PEAR_Error on failure.
      */
     function listFolder($path, $filter = null, $dotfiles = true,
                         $dironly = false, $recursive = false)
@@ -470,19 +429,16 @@ class VFS {
     }
 
     /**
-     * Returns a file list of the directory passed in.
-     *
-     * @access public
-     *
-     * @param string $path        The path of the directory.
-     * @param mixed $filter       String/hash to filter file/dirname on.
-     * @param boolean $dotfiles   Show dotfiles?
-     * @param boolean $dironly    Show only directories?
-     *
-     * @return array  File list on success.
-     *                Returns PEAR_Error on failure.
+     * Returns an an unsorted file list of the specified directory.
      *
      * @abstract
+     *
+     * @param string $path       The path of the directory.
+     * @param mixed $filter      String/hash to filter file/dirname on.
+     * @param boolean $dotfiles  Show dotfiles?
+     * @param boolean $dironly   Show only directories?
+     *
+     * @return array  File list on success or PEAR_Error on failure.
      */
     function _listFolder($path, $filter = null, $dotfiles = true,
                          $dironly = false)
@@ -493,8 +449,6 @@ class VFS {
     /**
      * Returns the current working directory of the VFS backend.
      *
-     * @access public
-     *
      * @return string  The current working directory.
      */
     function getCurrentDirectory()
@@ -503,8 +457,7 @@ class VFS {
     }
 
     /**
-     * Returns a boolean indicating whether or not the filename
-     * matches any filter element.
+     * Returns whether or not a filename matches any filter element.
      *
      * @access private
      *
@@ -547,16 +500,15 @@ class VFS {
     }
 
     /**
-     * Changes permissions for an Item on the VFS.
-     *
-     * @access public
-     *
-     * @param string $path  Holds the path of directory of the Item.
-     * @param string $name  Holds the name of the Item.
-     *
-     * @return mixed  True on success or a PEAR_Error object on failure.
+     * Changes permissions for an item on the VFS.
      *
      * @abstract
+     *
+     * @param string $path        The parent folder of the item.
+     * @param string $name        The name of the item.
+     * @param string $permission  The permission to set.
+     *
+     * @return mixed  True on success or a PEAR_Error object on failure.
      */
     function changePermissions($path, $name, $permission)
     {
@@ -564,19 +516,16 @@ class VFS {
     }
 
     /**
-     * Returns a sorted list of folders in specified directory.
-     *
-     * @access public
-     *
-     * @param optional string $path         The path of the directory to get
-     *                                      the directory list for.
-     * @param optional mixed $filter        Hash of items to filter based on
-     *                                      folderlist.
-     * @param optional boolean $dotfolders  Include dotfolders?
-     *
-     * @return mixed  Folder list on success or a PEAR_Error object on failure.
+     * Returns a sorted list of folders in the specified directory.
      *
      * @abstract
+     *
+     * @param string $path         The path of the directory to get the
+     *                             directory list for.
+     * @param mixed $filter        Hash of items to filter based on folderlist.
+     * @param boolean $dotfolders  Include dotfolders?
+     *
+     * @return mixed  Folder list on success or a PEAR_Error object on failure.
      */
     function listFolders($path = '', $filter = null, $dotfolders = true)
     {
@@ -584,9 +533,7 @@ class VFS {
     }
 
     /**
-     * Return the list of additional credentials required, if any.
-     *
-     * @access public
+     * Returns the list of additional credentials required, if any.
      *
      * @return array  Credential list.
      */
@@ -596,10 +543,8 @@ class VFS {
     }
 
     /**
-     * Return the array specificying what permissions are
-     * changeable for this implementation.
-     *
-     * @access public
+     * Returns an array specifying what permissions are changeable for this
+     * VFS implementation.
      *
      * @return array  Changeable permisions.
      */
@@ -609,10 +554,8 @@ class VFS {
     }
 
     /**
-     * Converts a string to all lowercase characters ignoring the
-     * current locale.
-     *
-     * @access public
+     * Converts a string to all lowercase characters ignoring the current
+     * locale.
      *
      * @param string $string  The string to be lowercased
      *
@@ -630,8 +573,6 @@ class VFS {
     /**
      * Returns the character (not byte) length of a string.
      *
-     * @access public
-     *
      * @param string $string   The string to return the length of.
      * @param string $charset  The charset to use when calculating the
      *                         string's length.
@@ -655,18 +596,14 @@ class VFS {
     /**
      * Attempts to return a concrete VFS instance based on $driver.
      *
-     * @access public
+     * @param mixed $driver  The type of concrete VFS subclass to return. This
+     *                       is based on the storage driver ($driver). The
+     *                       code is dynamically included.
+     * @param array $params  A hash containing any additional configuration or
+     *                       connection parameters a subclass might need.
      *
-     * @param mixed $driver           The type of concrete VFS subclass to
-     *                                return. This is based on the storage
-     *                                driver ($driver). The code is
-     *                                dynamically included.
-     * @param optional array $params  A hash containing any additional
-     *                                configuration or connection parameters a
-     *                                subclass might need.
-     *
-     * @return object VFS  The newly created concrete VFS instance,
-     *                     or a PEAR_Error on an error.
+     * @return VFS  The newly created concrete VFS instance, or a PEAR_Error
+     *              on failure.
      */
     function &factory($driver, $params = array())
     {
@@ -680,27 +617,22 @@ class VFS {
     }
 
     /**
-     * Attempts to return a reference to a concrete VFS instance
-     * based on $driver. It will only create a new instance if no
-     * VFS instance with the same parameters currently exists.
+     * Attempts to return a reference to a concrete VFS instance based on
+     * $driver. It will only create a new instance if no VFS instance with the
+     * same parameters currently exists.
      *
-     * This should be used if multiple types of file backends (and,
-     * thus, multiple VFS instances) are required.
+     * This should be used if multiple types of file backends (and, thus,
+     * multiple VFS instances) are required.
      *
      * This method must be invoked as: $var = &VFS::singleton()
      *
-     * @access public
+     * @param mixed $driver  The type of concrete VFS subclass to return. This
+     *                       is based on the storage driver ($driver). The
+     *                       code is dynamically included.
+     * @param array $params  A hash containing any additional configuration or
+     *                       connection parameters a subclass might need.
      *
-     * @param mixed $driver           The type of concrete VFS subclass to
-     *                                return. This is based on the storage
-     *                                driver ($driver). The code is
-     *                                dynamically included.
-     * @param optional array $params  A hash containing any additional
-     *                                configuration or connection parameters a
-     *                                subclass might need.
-     *
-     * @return object VFS  The concrete VFS reference, or a PEAR_Error on an
-     *                     error.
+     * @return VFS  The concrete VFS reference, or a PEAR_Error on failure.
      */
     function &singleton($driver, $params = array())
     {
