@@ -2,24 +2,21 @@
 /**
  * VFS implementation for a standard filesystem.
  *
- * <pre>
- * Required values for $params:
- *      'vfsroot'       The root path
- * </pre>
+ * Required parameters:<pre>
+ *   'vfsroot'  The root path</pre>
  *
  * Note: The user that your webserver runs as (commonly 'nobody',
  * 'apache', or 'www-data') MUST have read/write permission to the
  * directory you specific as the 'vfsroot'.
  *
- * $Horde: framework/VFS/VFS/file.php,v 1.63 2004/12/06 09:55:52 jan Exp $
+ * $Horde: framework/VFS/VFS/file.php,v 1.63.4.10 2005/07/03 04:52:42 selsky Exp $
  *
- * Copyright 2002-2004 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch
- * @version $Revision: 1.63 $
  * @since   Horde 2.2
  * @package VFS
  */
@@ -29,7 +26,7 @@ class VFS_file extends VFS {
      * List of permissions and if they can be changed in this VFS
      * backend.
      *
-     * @var array $_permissions
+     * @var array
      */
     var $_permissions = array(
         'owner' => array('read' => true, 'write' => true, 'execute' => true),
@@ -40,9 +37,7 @@ class VFS_file extends VFS {
     /**
      * Constructs a new Filesystem based VFS object.
      *
-     * @access public
-     *
-     * @param optional array $params  A hash containing connection parameters.
+     * @param array $params  A hash containing connection parameters.
      */
     function VFS_file($params = array())
     {
@@ -59,8 +54,6 @@ class VFS_file extends VFS {
     /**
      * Retrieve a file from the VFS.
      *
-     * @access public
-     *
      * @param string $path  The pathname to the file.
      * @param string $name  The filename to retrieve.
      *
@@ -73,7 +66,12 @@ class VFS_file extends VFS {
         if (!$fp) {
             return PEAR::raiseError(_("Unable to open VFS file."));
         }
-        $data = fread($fp, filesize($file));
+        $filesize = filesize($file);
+        if ($filesize == 0) {
+            $data = '';
+        } else {
+            $data = fread($fp, $filesize);
+        }
         fclose($fp);
 
         return $data;
@@ -83,13 +81,11 @@ class VFS_file extends VFS {
      * Store a file in the VFS, with the data copied from a temporary
      * file.
      *
-     * @access public
-     *
-     * @param string $path                  The path to store the file in.
-     * @param string $name                  The filename to use.
-     * @param string $tmpFile               The temporary file containing the
-     *                                      data to be stored.
-     * @param optional boolean $autocreate  Automatically create directories?
+     * @param string $path         The path to store the file in.
+     * @param string $name         The filename to use.
+     * @param string $tmpFile      The temporary file containing the data to be
+     *                             stored.
+     * @param boolean $autocreate  Automatically create directories?
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -120,8 +116,6 @@ class VFS_file extends VFS {
     /**
      * Moves a file in the database and the file system.
      *
-     * @access public
-     *
      * @param string $path  The path to store the file in.
      * @param string $name  The filename to use.
      *
@@ -146,8 +140,6 @@ class VFS_file extends VFS {
     /**
      * Copies a file through the backend.
      *
-     * @access public
-     *
      * @param string $path  The path to store the file in.
      * @param string $name  The filename to use.
      * @param string $dest  The destination of the file.
@@ -177,12 +169,10 @@ class VFS_file extends VFS {
     /**
      * Store a file in the VFS from raw data.
      *
-     * @access public
-     *
-     * @param string $path                  The path to store the file in.
-     * @param string $name                  The filename to use.
-     * @param string $data                  The file data.
-     * @param optional boolean $autocreate  Automatically create directories?
+     * @param string $path         The path to store the file in.
+     * @param string $name         The filename to use.
+     * @param string $data         The file data.
+     * @param boolean $autocreate  Automatically create directories?
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -225,8 +215,6 @@ class VFS_file extends VFS {
     /**
      * Delete a file from the VFS.
      *
-     * @access public
-     *
      * @param string $path  The path to store the file in.
      * @param string $name  The filename to use.
      *
@@ -237,16 +225,16 @@ class VFS_file extends VFS {
         if (!@unlink($this->_getNativePath($path, $name))) {
             return PEAR::raiseError(_("Unable to delete VFS file."));
         }
+
+        return true;
     }
 
     /**
      * Delete a folder from the VFS.
      *
-     * @access public
-     *
-     * @param string $path                 The path to delete the folder from.
-     * @param string $name                 The foldername to use.
-     * @param optional boolean $recursive  Force a recursive delete?
+     * @param string $path        The path to delete the folder from.
+     * @param string $name        The foldername to use.
+     * @param boolean $recursive  Force a recursive delete?
      *
      * @return mixed True on success or a PEAR_Error object on failure.
      */
@@ -278,8 +266,6 @@ class VFS_file extends VFS {
     /**
      * Creates a folder on the VFS.
      *
-     * @access public
-     *
      * @param string $path  The path to delete the folder from.
      * @param string $name  The foldername to use.
      *
@@ -297,8 +283,6 @@ class VFS_file extends VFS {
     /**
      * Check if a given pathname is a folder.
      *
-     * @access public
-     *
      * @param string $path  The path to the folder.
      * @param string $name  The file/folder name.
      *
@@ -312,8 +296,6 @@ class VFS_file extends VFS {
     /**
      * Changes permissions for an item in the VFS.
      *
-     * @access public
-     *
      * @param string $path         The path of directory of the item.
      * @param string $name         The name of the item.
      * @param integer $permission  The octal value of the new permission.
@@ -332,18 +314,15 @@ class VFS_file extends VFS {
     /**
      * Return a list of the contents of a folder.
      *
-     * @access public
-     *
-     * @param string $path                The path of the directory.
-     * @param optional mixed $filter      String/hash to filter file/dirname
-     *                                    on.
-     * @param optional boolean $dotfiles  Show dotfiles?
-     * @param optional boolean $dironly   Show only directories?
+     * @param string $path       The path of the directory.
+     * @param mixed $filter      String/hash to filter file/dirname on.
+     * @param boolean $dotfiles  Show dotfiles?
+     * @param boolean $dironly   Show only directories?
      *
      * @return array  File list on success, PEAR_Error on error.
      */
     function _listFolder($path, $filter = null, $dotfiles = true,
-                        $dironly = false)
+                         $dironly = false)
     {
         $files = array();
         $path = isset($path) ? $this->_getNativePath($path) : $this->_getNativePath();
@@ -462,13 +441,10 @@ class VFS_file extends VFS {
     /**
      * Returns a sorted list of folders in specified directory.
      *
-     * @access public
-     *
-     * @param optional string $path         The path of the directory to get
-     *                                      the directory list for.
-     * @param optional mixed $filter        Hash of items to filter based on
-     *                                      folderlist.
-     * @param optional boolean $dotfolders  Include dotfolders?
+     * @param string $path         The path of the directory to get the
+     *                             directory list for.
+     * @param mixed $filter        Hash of items to filter based on folderlist.
+     * @param boolean $dotfolders  Include dotfolders?
      *
      * @return mixed  Folder list on success or a PEAR_Error object on failure.
      */
@@ -489,10 +465,10 @@ class VFS_file extends VFS {
             return $folderList;
         }
 
-        foreach ($folderList as $files) {
-            $folders[$folder['val']] = array('val' => $path . '/' . $files['name'],
-                                             'abbrev' => $files['name'],
-                                             'label' => $path . '/' . $files['name']);
+        foreach ($folderList as $name => $files) {
+            $folders[$name] = array('val' => $path . '/' . $files['name'],
+                                    'abbrev' => $files['name'],
+                                    'label' => $path . '/' . $files['name']);
         }
 
         ksort($folders);
@@ -543,8 +519,6 @@ class VFS_file extends VFS {
     /**
      * Rename a file or folder in the VFS.
      *
-     * @access public
-     *
      * @param string $oldpath  The old path to the file.
      * @param string $oldname  The old filename.
      * @param string $newpath  The new path of the file.
@@ -568,8 +542,8 @@ class VFS_file extends VFS {
      *
      * @access private
      *
-     * @param optional string $path  The VFS file path.
-     * @param optional string $name  The VFS filename.
+     * @param string $path  The VFS file path.
+     * @param string $name  The VFS filename.
      *
      * @return string  The full native filename.
      */
