@@ -2,21 +2,20 @@
 /**
  * VFS implementation for an FTP server.
  *
- * <pre>
- * Required values for $params:
+ * Required values for $params:<pre>
  *      'username'       The username with which to connect to the ftp server.
  *      'password'       The password with which to connect to the ftp server.
- *      'hostspec'       The ftp server to connect to.
- * Optional values for $params:
+ *      'hostspec'       The ftp server to connect to.</pre>
+ *
+ * Optional values for $params:<pre>
  *      'pasv'           If true, connection will be set to passive mode.
  *      'port'           The port used to connect to the ftp server if other
  *                       than 21.
  *      'ssl'            If true, and PHP had been compiled with OpenSSL
  *                       support, TLS transport-level encryption will be
- *                       negotiated with the server.
- * </pre>
+ *                       negotiated with the server.</pre>
  *
- * $Horde: framework/VFS/VFS/ftp.php,v 1.75.4.2 2005/01/03 12:19:20 jan Exp $
+ * $Horde: framework/VFS/VFS/ftp.php,v 1.75.4.9 2005/08/24 14:04:39 selsky Exp $
  *
  * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2002-2005 Michael Varghese <mike.varghese@ascellatech.com>
@@ -26,7 +25,6 @@
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Michael Varghese <mike.varghese@ascellatech.com>
- * @version $Revision: 1.75.4.2 $
  * @since   Horde 2.2
  * @package VFS
  */
@@ -35,15 +33,14 @@ class VFS_ftp extends VFS {
     /**
      * List of additional credentials required for this VFS backend.
      *
-     * @var array $_credentials
+     * @var array
      */
     var $_credentials = array('username', 'password');
 
     /**
-     * List of permissions and if they can be changed in this VFS
-     * backend.
+     * List of permissions and if they can be changed in this VFS backend.
      *
-     * @var array $_permissions
+     * @var array
      */
     var $_permissions = array(
         'owner' => array('read' => true, 'write' => true, 'execute' => true),
@@ -53,14 +50,12 @@ class VFS_ftp extends VFS {
     /**
      * Variable holding the connection to the ftp server.
      *
-     * @var resource $_stream
+     * @var resource
      */
     var $_stream = false;
 
     /**
-     * Retrieve a file from the VFS.
-     *
-     * @access public
+     * Retrieves a file from the VFS.
      *
      * @param string $path  The pathname to the file.
      * @param string $name  The filename to retrieve.
@@ -81,28 +76,32 @@ class VFS_ftp extends VFS {
             return PEAR::raiseError(sprintf(_("Unable to open VFS file \"%s\"."), $this->_getPath($path, $name)));
         }
 
+        $size = filesize($tmpFile);
+        if ($size === 0) {
+            return '';
+        }
+
         if (OS_WINDOWS) {
             $mode = 'rb';
         } else {
             $mode = 'r';
         }
         $fp = fopen($tmpFile, $mode);
-        $data = fread($fp, filesize($tmpFile));
+        $data = fread($fp, $size);
         fclose($fp);
         unlink($tmpFile);
+
         return $data;
     }
 
     /**
-     * Store a file in the VFS.
+     * Stores a file in the VFS.
      *
-     * @access public
-     *
-     * @param string $path                  The path to store the file in.
-     * @param string $name                  The filename to use.
-     * @param string $tmpFile               The temporary file containing the
-     *                                      data to be stored.
-     * @param optional boolean $autocreate  Automatically create directories?
+     * @param string $path         The path to store the file in.
+     * @param string $name         The filename to use.
+     * @param string $tmpFile      The temporary file containing the data to
+     *                             be stored.
+     * @param boolean $autocreate  Automatically create directories?
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -131,14 +130,12 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Store a file in the VFS from raw data.
+     * Stores a file in the VFS from raw data.
      *
-     * @access public
-     *
-     * @param string $path                  The path to store the file in.
-     * @param string $name                  The filename to use.
-     * @param string $data                  The file data.
-     * @param optional boolean $autocreate  Automatically create directories?
+     * @param string $path         The path to store the file in.
+     * @param string $name         The filename to use.
+     * @param string $data         The file data.
+     * @param boolean $autocreate  Automatically create directories?
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -155,12 +152,10 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Delete a file from the VFS.
-     *
-     * @access public
+     * Deletes a file from the VFS.
      *
      * @param string $path  The path to delete the file from.
-     * @param string $name  The filename to use.
+     * @param string $name  The filename to delete.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -179,12 +174,10 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Check if a given pathname is a folder.
+     * Checks if a given item is a folder.
      *
-     * @access public
-     *
-     * @param string $path  The path to the folder.
-     * @param string $name  The file/folder name.
+     * @param string $path  The parent folder.
+     * @param string $name  The item name.
      *
      * @return boolean  True if it is a folder, false otherwise.
      */
@@ -209,13 +202,11 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Delete a folder from the VFS.
+     * Deletes a folder from the VFS.
      *
-     * @access public
-     *
-     * @param string $path                 The path to delete the folder from.
-     * @param string $name                 The name of the folder to delete.
-     * @param optional boolean $recursive  Force a recursive delete?
+     * @param string $path        The parent folder.
+     * @param string $name        The name of the folder to delete.
+     * @param boolean $recursive  Force a recursive delete?
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -270,9 +261,7 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Rename a file in the VFS.
-     *
-     * @access public
+     * Renames a file in the VFS.
      *
      * @param string $oldpath  The old path to the file.
      * @param string $oldname  The old filename.
@@ -298,10 +287,8 @@ class VFS_ftp extends VFS {
     /**
      * Creates a folder on the VFS.
      *
-     * @access public
-     *
-     * @param string $path  Holds the path of directory to create folder.
-     * @param string $name  Holds the name of the new folder.
+     * @param string $path  The parent folder.
+     * @param string $name  The name of the new folder.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -320,13 +307,11 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Changes permissions for an Item on the VFS.
+     * Changes permissions for an item on the VFS.
      *
-     * @access public
-     *
-     * @param string $path        Holds the path of directory of the Item.
-     * @param string $name        Holds the name of the Item.
-     * @param string $permission  TODO
+     * @param string $path        The parent folder of the item.
+     * @param string $name        The name of the item.
+     * @param string $permission  The permission to set.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -345,21 +330,17 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Returns an unsorted file list.
+     * Returns an an unsorted file list of the specified directory.
      *
-     * @access public
+     * @param string $path       The path of the directory.
+     * @param mixed $filter      String/hash to filter file/dirname on.
+     * @param boolean $dotfiles  Show dotfiles?
+     * @param boolean $dironly   Show only directories?
      *
-     * @param optional string $path       The path of the directory to get the
-     *                                    file list for.
-     * @param optional mixed $filter      Hash of items to filter based on
-     *                                    filename.
-     * @param optional boolean $dotfiles  Show dotfiles?
-     * @param optional boolean $dironly   Show directories only?
-     *
-     * @return mixed  File list on success or a PEAR_Error object on failure.
+     * @return array  File list on success or PEAR_Error on failure.
      */
     function _listFolder($path = '', $filter = null, $dotfiles = true,
-                        $dironly = false)
+                         $dironly = false)
     {
         $conn = $this->_connect();
         if (is_a($conn, 'PEAR_Error')) {
@@ -520,15 +501,12 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Returns a sorted list of folders in specified directory.
+     * Returns a sorted list of folders in the specified directory.
      *
-     * @access public
-     *
-     * @param optional string $path         The path of the directory to get
-     *                                      the directory list for.
-     * @param optional mixed $filter        Hash of items to filter based on
-     *                                      folderlist.
-     * @param optional boolean $dotfolders  Include dotfolders?
+     * @param string $path         The path of the directory to get the
+     *                             directory list for.
+     * @param mixed $filter        Hash of items to filter based on folderlist.
+     * @param boolean $dotfolders  Include dotfolders?
      *
      * @return mixed  Folder list on success or a PEAR_Error object on failure.
      */
@@ -568,11 +546,9 @@ class VFS_ftp extends VFS {
     /**
      * Copies a file through the backend.
      *
-     * @access public
-     *
-     * @param string $path  The path to store the file in.
-     * @param string $name  The filename to use.
-     * @param string $dest  The destination of the file.
+     * @param string $path  The path of the original file.
+     * @param string $name  The name of the original file.
+     * @param string $dest  The name of the destination directory.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -641,11 +617,9 @@ class VFS_ftp extends VFS {
     /**
      * Moves a file through the backend.
      *
-     * @access public
-     *
-     * @param string $path  The path to store the file in.
-     * @param string $name  The filename to use.
-     * @param string $dest  The destination of the file.
+     * @param string $path  The path of the original file.
+     * @param string $name  The name of the original file.
+     * @param string $dest  The destination file name.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -671,9 +645,7 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Return the current working directory on the FTP server.
-     *
-     * @access public
+     * Returns the current working directory on the FTP server.
      *
      * @return string  The current working directory.
      */
@@ -686,7 +658,7 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Change directories on the server.
+     * Changes the current directory on the server.
      *
      * @access private
      *
@@ -707,10 +679,11 @@ class VFS_ftp extends VFS {
      *
      * @access private
      *
-     * @param string $path  Holds the path of directory of the Item.
-     * @param string $name  Holds the name of the Item.
+     * @param string $path  The directory of the item.
+     * @param string $name  The name of the item.
      *
-     * @return mixed  Full path when $path isset and just $name when not set.
+     * @return mixed  Full path to the file when $path is not empty and just
+     *                $name when not set.
      */
     function _getPath($path, $name)
     {
@@ -721,14 +694,14 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Returns the parent directory of specified path.
+     * Returns the parent directory of the specified path.
      *
      * @access private
      *
      * @param string $path  The path to get the parent of.
      *
-     * @return mixed  The parent directory (string) on success
-     *                or a PEAR_Error object on failure.
+     * @return string  The parent directory (string) on success or a PEAR_Error
+     *                 object on failure.
      */
     function _parentDir($path)
     {
@@ -771,7 +744,7 @@ class VFS_ftp extends VFS {
             $required = array('hostspec', 'username', 'password');
             foreach ($required as $val) {
                 if (!isset($this->_params[$val])) {
-                    return PEAR::raiseError(sprintf(_("Required '%s' not specified in VFS configuration."), $val));
+                    return PEAR::raiseError(sprintf(_("Required \"%s\" not specified in VFS configuration."), $val));
                 }
             }
 
@@ -804,7 +777,7 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Disconnect from the FTP server and clean up the connection.
+     * Disconnects from the FTP server and cleans up the connection.
      *
      * @access private
      */
@@ -815,7 +788,7 @@ class VFS_ftp extends VFS {
     }
 
     /**
-     * Determine the location of the system temporary directory.  If a
+     * Determines the location of the system temporary directory.  If a
      * specific setting cannot be found, it defaults to /tmp
      *
      * @access private
@@ -830,14 +803,13 @@ class VFS_ftp extends VFS {
         /* Try PHP's upload_tmp_dir directive. */
         $tmp = ini_get('upload_tmp_dir');
 
-        /* Otherwise, try to determine the TMPDIR environment
-           variable. */
+        /* Otherwise, try to determine the TMPDIR environment variable. */
         if (empty($tmp)) {
             $tmp = getenv('TMPDIR');
         }
 
-        /* If we still cannot determine a value, then cycle through a
-         * list of preset possibilities. */
+        /* If we still cannot determine a value, then cycle through a list of
+         * preset possibilities. */
         while (empty($tmp) && sizeof($tmp_locations)) {
             $tmp_check = array_shift($tmp_locations);
             if (@is_dir($tmp_check)) {
@@ -845,13 +817,13 @@ class VFS_ftp extends VFS {
             }
         }
 
-        /* If it is still empty, we have failed, so return false;
-         * otherwise return the directory determined. */
+        /* If it is still empty, we have failed, so return false; otherwise
+         * return the directory determined. */
         return empty($tmp) ? false : $tmp;
     }
 
     /**
-     * Create a temporary file.
+     * Creates a temporary file.
      *
      * @access private
      *
@@ -867,7 +839,7 @@ class VFS_ftp extends VFS {
 
         $tmp_file = tempnam($tmp_dir, 'vfs');
 
-        /* If the file was created, then register it for deletion and return */
+        /* If the file was created, then register it for deleton and return */
         if (empty($tmp_file)) {
             return false;
         } else {
