@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: horde/lib/prefs.php,v 1.19.4.1 2005/01/03 12:25:41 jan Exp $
+ * $Horde: horde/lib/prefs.php,v 1.19.4.7 2005/05/25 13:15:09 jan Exp $
  *
  * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2005 Jon Parise <jon@horde.org>
@@ -41,8 +41,9 @@ function handle_categorymanagement($updated)
     $cManager = &new Prefs_CategoryManager();
 
     /* Always save colors of all categories. */
-    $colors = array_unique(array_merge($cManager->get(), array_keys($cManager->colors())));
-    foreach ($colors as $category) {
+    $colors = array();
+    $categories = $cManager->get();
+    foreach ($categories as $category) {
         if ($color = Util::getFormData('color_' . base64_encode($category))) {
             $colors[$category] = $color;
         }
@@ -84,7 +85,7 @@ function prefs_callback()
     }
 
     if ($prefs->isDirty('language') ||
-        $prefs->isDirty('sidebar_width')) {
+        $prefs->isDirty('show_sidebar')) {
         $url = $registry->get('webroot', 'horde');
         if (substr($url, -1) != '/') {
             $url .= '/';
@@ -93,8 +94,13 @@ function prefs_callback()
         $notification->push('if (window.parent.frames) window.parent.frames.location = \'' . addslashes(Horde::url($url, true)) . '\';', 'javascript');
     }
 
+    if ($prefs->isDirty('sidebar_width')) {
+        $notification->push('if (window.parent && window.parent.document.getElementById(\'hf\') && window.parent.horde_menu && window.parent.horde_menu.expandedSidebar.shown()) window.parent.document.getElementById(\'hf\').cols = window.parent.horde_menu.rtl ? \'*,' . $prefs->getValue('sidebar_width') . '\' : \'' . $prefs->getValue('sidebar_width') . ',*\';', 'javascript');
+    }
+
     if ($prefs->isDirty('theme') ||
-        $prefs->isDirty('menu_view')) {
+        $prefs->isDirty('menu_view') ||
+        $prefs->isDirty('menu_refresh_time')) {
         $notification->push('if (window.parent.frames.horde_menu) window.parent.frames.horde_menu.location.reload();', 'javascript');
     }
 }
@@ -102,6 +108,7 @@ function prefs_callback()
 /* Assign variables for select lists. */
 if (!$prefs->isLocked('timezone')) {
     $timezone_options = &$tz;
+    array_unshift($timezone_options, _("Default"));
 }
 if (!$prefs->isLocked('initial_application')) {
     global $perms;
@@ -109,8 +116,9 @@ if (!$prefs->isLocked('initial_application')) {
     $initial_application_options = array();
     $apps = $registry->listApps(array('active'));
     foreach ($apps as $a) {
-        if (($perms->exists($a) && ($perms->hasPermission($a, Auth::getAuth(), PERMS_READ) || Auth::isAdmin())) ||
-            !$perms->exists($a)) {
+        if (file_exists($registry->get('fileroot', $a)) &&
+            (($perms->exists($a) && ($perms->hasPermission($a, Auth::getAuth(), PERMS_READ) || Auth::isAdmin())) ||
+             !$perms->exists($a))) {
             $initial_application_options[$a] = $registry->get('name', $a);
         }
     }
